@@ -1,6 +1,6 @@
 // callbacks.h
 // LiVES
-// (c) G. Finch <salsaman@xs4all.nl,salsaman@gmail.com> 2003 - 2013
+// (c) G. Finch <salsaman@gmail.com> 2003 - 2013
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -141,10 +141,9 @@ on_rev_clipboard_activate              (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
 void 
-on_encoder_entry_changed(GtkComboBox *combo, gpointer ptr);
+on_encoder_entry_changed(GtkComboBox *, gpointer ptr);
 
-void 
-on_vid_playback_plugin_changed (GtkEntry *vpp_entry, gpointer user_data);
+void on_vid_playback_plugin_changed (GtkEntry *vpp_entry, gpointer user_data);
 
 
 void
@@ -192,14 +191,11 @@ on_ok_button1_clicked                  (GtkButton       *button,
                                         gpointer         user_data);
 
 
-void on_ok_file_open_clicked(GtkFileChooser *chooser, GSList *fnames);
+void on_ok_file_open_clicked(GtkFileChooser *, GSList *fnames);
 
-void on_ok_filesel_open_clicked (GtkFileChooser *chooser, gpointer user_data);
+void on_ok_filesel_open_clicked (GtkFileChooser *, gpointer);
 
-
-
-void
-open_sel_range_activate                 (void);
+void open_sel_range_activate (void);
 
 
 
@@ -220,18 +216,11 @@ on_opensel_range_ok_clicked                  (GtkButton       *button,
 					      gpointer         user_data);
 
 
-void
-on_open_sel_ok_button_clicked                  (GtkButton       *button,
-                                        gpointer         user_data);
+void on_open_sel_ok_button_clicked (GtkButton *, gpointer user_data);
 
+void on_save_textview_clicked (GtkButton *, gpointer);
 
-void on_save_textview_clicked (GtkButton *button, gpointer user_data);
-
-void
-on_cancel_button1_clicked              (GtkWidget       *widget,
-                                        gpointer         user_data);
-
-gboolean on_cancel_button1_clicked_del(GtkWidget *widget, GdkEvent *event, gpointer user_data);
+void on_cancel_button1_clicked (GtkWidget *, gpointer data_to_free);
 
 
 void
@@ -305,26 +294,15 @@ void
 on_spinbutton_end_value_changed          (GtkSpinButton   *spinbutton,
 					  gpointer         user_data);
 
-void on_open_new_audio_clicked (GtkFileChooser *chooser, gpointer opt_filename);
+void on_open_new_audio_clicked (GtkFileChooser *, gpointer opt_filename);
 
-void on_load_audio_activate (GtkMenuItem *, gpointer user_data);
+void on_load_audio_activate (GtkMenuItem *, gpointer);
 
-void on_load_subs_activate (GtkMenuItem *menuitem, gpointer user_data);
+void on_load_subs_activate (GtkMenuItem *, gpointer);
 
-void on_save_subs_activate (GtkMenuItem *menuitem, gpointer entry_widget);
+void on_save_subs_activate (GtkMenuItem *, gpointer entry_widget);
 
-void on_erase_subs_activate (GtkMenuItem *menuitem, gpointer user_data);
-
-
-void
-on_xmms_play_audio_activate                  (GtkMenuItem     *menuitem,
-					      gpointer         user_data);
-
-void on_xmms_ok_clicked (GtkFileChooser *chooser, gpointer user_data);
-
-void 
-on_xmms_stop_audio_activate                (GtkMenuItem     *menuitem,
-					    gpointer         user_data);
+void on_erase_subs_activate (GtkMenuItem *, gpointer);
 
 
 void 
@@ -360,14 +338,24 @@ void
 on_spin_end_value_changed           (GtkSpinButton   *spinbutton,
 				       gpointer         user_data);
 
-gint
-expose_vid_event (GtkWidget *widget, GdkEventExpose *event);
 
-gint
-expose_laud_event (GtkWidget *widget, GdkEventExpose *event);
+#if GTK_CHECK_VERSION(3,0,0)
+boolean expose_vid_event (GtkWidget *, lives_painter_t *cr, gpointer user_data);
+#else
+boolean expose_vid_event (GtkWidget *, GdkEventExpose *event);
+#endif
 
-gint
-expose_raud_event (GtkWidget *widget, GdkEventExpose *event);
+#if GTK_CHECK_VERSION(3,0,0)
+boolean expose_laud_event (GtkWidget *, lives_painter_t *cr, gpointer user_data);
+#else
+boolean expose_laud_event (GtkWidget *, GdkEventExpose *event);
+#endif
+
+#if GTK_CHECK_VERSION(3,0,0)
+boolean expose_raud_event (GtkWidget *, lives_painter_t *cr, gpointer user_data);
+#else
+boolean expose_raud_event (GtkWidget *, GdkEventExpose *event);
+#endif
 
 
 
@@ -379,7 +367,7 @@ void
 on_recent_activate                      (GtkMenuItem     *menuitem,
 					 gpointer         user_data);
 
-gboolean config_event (GtkWidget *widget, GdkEventConfigure *event, gpointer user_data);
+boolean config_event (GtkWidget *, GdkEventConfigure *, gpointer);
 
 void
 changed_fps_during_pb           (GtkSpinButton   *spinbutton,
@@ -433,12 +421,9 @@ void
 on_forward_pressed (GtkButton *button,
 		   gpointer user_data);
 
-void
-on_capture_activate                (GtkMenuItem     *menuitem,
-				    gpointer         user_data);
+void on_capture_activate (GtkMenuItem *, gpointer user_data);
 
-void 
-on_capture2_activate(void);
+void on_capture2_activate(void);
 
 
 void
@@ -465,27 +450,20 @@ void
 on_backup_activate                      (GtkMenuItem     *menuitem,
 					 gpointer         user_data);
 
-void
-on_xmms_ran_ok_clicked                  (GtkButton       *button,
-				       gpointer         user_data);
-
 
 void
 on_record_perf_activate                      (GtkMenuItem     *menuitem,
 					      gpointer         user_data);
 
-gboolean record_toggle_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data);
+gboolean record_toggle_callback (GtkAccelGroup *, GObject *, guint keyval, GdkModifierType mod, gpointer);
 
 
-gboolean fps_reset_callback (GtkAccelGroup *, GObject *, guint, GdkModifierType, gpointer user_data);
+gboolean fps_reset_callback (GtkAccelGroup *, GObject *, guint keyval, GdkModifierType mod, gpointer);
 
 
-gboolean mute_audio_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer);
+gboolean mute_audio_callback (GtkAccelGroup *, GObject *, guint keyval, GdkModifierType mod, gpointer);
 
 
-void
-on_xmms_random_audio_activate                (GtkMenuItem     *menuitem,
-					      gpointer         user_data);
 
 gboolean
 on_stop_activate_by_del                  (GtkWidget       *widget,
@@ -504,16 +482,9 @@ on_select_end_only_activate                (GtkMenuItem     *menuitem,
 					    gpointer         user_data);
 
 void
-on_filesel_simple_clicked                      (GtkButton *button,
-						GtkEntry *entry);
-void
 on_filesel_complex_clicked                      (GtkButton *button,
 						GtkEntry *entry);
 
-void
-on_filesel_simple_ok_clicked                      (GtkButton *button,
-						   GtkEntry *entry);
-
 void
 on_filesel_complex_ok_clicked                      (GtkButton *button,
 						   GtkEntry *entry);
@@ -525,9 +496,7 @@ void
 on_ok_export_audio_clicked                      (GtkButton *button,
 						 gpointer user_data);
 
-void
-on_append_audio_activate (GtkMenuItem     *menuitem,
-			  gpointer         user_data);
+void on_append_audio_activate (GtkMenuItem *, gpointer user_data);
 
 void
 on_menubar_activate_menuitem                    (GtkMenuItem     *menuitem,
@@ -550,20 +519,14 @@ void
 on_recaudclip_ok_clicked                      (GtkButton *button,
 					       gpointer user_data);
 #if GTK_CHECK_VERSION(2,14,0)
-void
-on_volume_slider_value_changed           (GtkScaleButton   *sbutton,
-					  gpointer user_data);
+void on_volume_slider_value_changed (GtkScaleButton *, gpointer);
 #else
-void
-on_volume_slider_value_changed           (GtkRange   *slider,
-					  gpointer user_data);
+void on_volume_slider_value_changed (GtkRange *, gpointer);
 #endif
 
-void
-on_fade_audio_activate (GtkMenuItem     *menuitem,
-			  gpointer         user_data);
+void on_fade_audio_activate (GtkMenuItem *, gpointer user_data);
 
-void on_ok_append_audio_clicked (GtkFileChooser *chooser, gpointer user_data);
+void on_ok_append_audio_clicked (GtkFileChooser *, gpointer);
 
 void
 on_resample_video_activate (GtkMenuItem     *menuitem,
@@ -573,9 +536,7 @@ void
 on_resample_vid_ok                  (GtkButton       *button,
 				  GtkEntry         *entry);
 
-void
-on_trim_audio_activate (GtkMenuItem     *menuitem,
-			gpointer         user_data);
+void on_trim_audio_activate (GtkMenuItem *, gpointer user_data);
 
 void
 on_resample_audio_activate (GtkMenuItem     *menuitem,
@@ -603,8 +564,7 @@ void
 on_sticky_activate               (GtkMenuItem     *menuitem,
 				  gpointer         user_data);
 
-void 
-on_resaudw_asamps_changed (GtkWidget *irrelevant, gpointer rubbish);
+void on_resaudw_asamps_changed (GtkWidget *, gpointer);
 
 
 void 
@@ -624,8 +584,7 @@ void
 on_show_messages_activate            (GtkMenuItem     *menuitem,
 				      gpointer         user_data);
 
-gboolean
-on_hrule_enter (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data);
+gboolean on_hrule_enter (GtkWidget *, GdkEventCrossing *, gpointer);
 
 gboolean
 on_hrule_update           (GtkWidget       *widget,
@@ -668,35 +627,29 @@ void
 on_preview_spinbutton_changed          (GtkSpinButton   *spinbutton,
 					  gpointer         user_data);
 
-gboolean prevclip_callback (GtkAccelGroup *, GObject *, guint, GdkModifierType, gpointer user_data);
+gboolean prevclip_callback (GtkAccelGroup *, GObject *, guint, GdkModifierType, gpointer );
 
-gboolean nextclip_callback (GtkAccelGroup *, GObject *, guint, GdkModifierType, gpointer user_data);
+gboolean nextclip_callback (GtkAccelGroup *, GObject *, guint, GdkModifierType, gpointer );
 
-gboolean freeze_callback (GtkAccelGroup *, GObject *, guint, GdkModifierType, gpointer user_data);
+gboolean freeze_callback (GtkAccelGroup *, GObject *, guint, GdkModifierType, gpointer );
 
-gboolean storeclip_callback (GtkAccelGroup *, GObject *, guint, GdkModifierType, gpointer user_data);
+gboolean storeclip_callback (GtkAccelGroup *, GObject *, guint, GdkModifierType, gpointer );
 
-gboolean nervous_callback (GtkAccelGroup *, GObject *, guint, GdkModifierType, gpointer user_data);
+gboolean nervous_callback (GtkAccelGroup *, GObject *, guint, GdkModifierType, gpointer );
 
-gboolean show_sync_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer clip_number);
+gboolean show_sync_callback (GtkAccelGroup *, GObject *, guint keyval, GdkModifierType mod, gpointer clip_number);
 
-void on_save_set_activate (GtkMenuItem *, gpointer user_data);
+void on_save_set_activate (GtkMenuItem *, gpointer );
 
 void on_save_set_ok (void);
 
-void on_load_set_activate (GtkMenuItem *, gpointer user_data);
+void on_load_set_activate (GtkMenuItem *, gpointer );
 
 gboolean on_load_set_ok (GtkButton *, gpointer skip_threaded_dialog);
 
+void on_open_vcd_activate (GtkMenuItem *, gpointer int_type);
 
-void
-on_open_vcd_activate                      (GtkMenuItem     *menuitem,
-					   gpointer         user_data);
-
-
-void 
-on_load_vcd_ok_clicked                (GtkButton     *button,
-				       gpointer         user_data);
+void on_load_vcd_ok_clicked (GtkButton *, gpointer user_data);
 
 
 
@@ -713,9 +666,6 @@ void
 on_vj_reset_activate            (GtkMenuItem     *menuitem,
 				 gpointer         user_data);
 
-gint
-expose_play_window (GtkWidget *widget, GdkEventExpose *event);
-
 void
 on_prv_link_toggled                (GtkToggleButton *togglebutton,
 				    gpointer         user_data);
@@ -727,14 +677,14 @@ void
 on_ins_silence_activate (GtkMenuItem     *menuitem,
 			 gpointer         user_data);
 
-void on_ins_silence_details_clicked (GtkButton *, gpointer user_data);
+void on_ins_silence_details_clicked (GtkButton *, gpointer);
 
 void on_lerrors_close_clicked (GtkButton *, gpointer);
 void on_lerrors_clear_clicked (GtkButton *, gpointer);
 void on_lerrors_delete_clicked (GtkButton *, gpointer);
 
-void drag_from_outside(GtkWidget *widget, GdkDragContext *dcon, gint x, gint y, 
-		       GtkSelectionData *data, guint info, guint time, gpointer user_data);
+void drag_from_outside(GtkWidget *, GdkDragContext *, gint x, gint y, 
+		       GtkSelectionData *, guint info, guint time, gpointer user_data);
 
 
 
