@@ -1,6 +1,6 @@
 // jack.c
 // LiVES (lives-exe)
-// (c) G. Finch 2005 - 2012
+// (c) G. Finch 2005 - 2013
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -112,15 +112,18 @@ boolean lives_jack_init (void) {
 
 
 
-gdouble jack_transport_get_time(void) {
+uint64_t jack_transport_get_time(void) {
 #ifdef ENABLE_JACK_TRANSPORT
+  uint64_t val;
+
   jack_nframes_t srate; 
   jack_position_t pos;
 
   jack_transport_query (jack_transport_client, &pos);
 
   srate=jack_get_sample_rate(jack_transport_client);
-  return (gdouble)pos.frame/(gdouble)srate;
+  val=(double)pos.frame/(double)srate;
+  if (val>0.) return val;
 #endif
   return 0.;
 }
@@ -583,7 +586,7 @@ static int audio_process (nframes_t nframes, void *arg) {
 
 	if (!from_memory) {
 	  //	if (((gint)(jackd->num_calls/100.))*100==jackd->num_calls) if (mainw->soft_debug) g_print("audio pip\n");
-	  if (mainw->agen_key!=0||mainw->agen_needs_reinit||cache_buffer->bufferf!=NULL) {
+	  if ((mainw->agen_key!=0||mainw->agen_needs_reinit||cache_buffer->bufferf!=NULL)&&!jackd->mute) {
 	    float *fbuffer=NULL;
 
 	    if (mainw->agen_key!=0||mainw->agen_needs_reinit) {
@@ -1147,7 +1150,7 @@ int jack_open_device(jack_driver_t *jackd) {
      just decides to stop calling us. */
   jack_on_shutdown(jackd->client, jack_shutdown, jackd);
 
-  jack_set_process_callback ((void *)jackd->client, audio_process, jackd);  
+  jack_set_process_callback ((jack_client_t *)jackd->client, audio_process, jackd);  
 
   return 0;
 
