@@ -1,6 +1,6 @@
 // main.h
 // LiVES
-// (c) G. Finch (salsaman@xs4all.nl,salsaman@gmail.com) 2003 - 2013
+// (c) G. Finch (salsaman@gmail.com) 2003 - 2013
 // see file ../COPYING for full licensing details
 
 /*  This program is free software; you can redistribute it and/or modify
@@ -52,15 +52,23 @@ POSSIBILITY OF SUCH DAMAGES.
 #define HAS_LIVES_MAIN_H
 
 #define GUI_GTK
+#define PAINTER_CAIRO
 
 #ifdef GUI_GTK
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
+#if GTK_CHECK_VERSION(3,0,0)
+#ifdef ENABLE_GIW
+#define ENABLE_GIW_3
+#endif
+#endif
+
+#endif
+
 #ifdef IS_MINGW
 
-#undef GDK_WINDOWING_X11
 #ifndef WINVER
 #define WINVER 0x0500
 #endif
@@ -76,9 +84,19 @@ POSSIBILITY OF SUCH DAMAGES.
 typedef PROCESS_INFORMATION * lives_pid_t;
 typedef PROCESS_INFORMATION * lives_pgid_t;
 
-#include <gdk/gdkwin32.h>
+#ifdef GUI_GTK
+#ifndef GDK_WINDOWING_WIN32
+#define GDK_WINDOWING_WIN32
+#endif
+#endif
 
-#else
+#else // IS_MINGW
+
+#ifdef GUI_GTK
+#ifndef GDK_WINDOWING_X11
+#define GDK_WINDOWING_X11
+#endif
+#endif
 
 typedef pid_t lives_pid_t;
 typedef int lives_pgid_t;
@@ -86,17 +104,45 @@ typedef int lives_pgid_t;
 #endif
 
 
+
+#ifdef GUI_GTK
+
+#ifdef GDK_WINDOWING_WIN32
+#include <gdk/gdkwin32.h>
+
+#ifndef GDK_IS_WIN32_DISPLAY 
+#define GDK_IS_WIN32_DISPLAY(display) (TRUE)
+#endif
+
+#endif //GDK_WINDOWING_WIN32
+
 #ifdef GDK_WINDOWING_X11
-#define USE_X11
 
 // needed for GDK_WINDOW_XID - for fileselector preview
 // needed for gdk_x11_screen_get_window_manager_name()
 
 #include <gdk/gdkx.h>
+
+#ifndef GDK_IS_X11_DISPLAY 
+#define GDK_IS_X11_DISPLAY(display) (TRUE)
 #endif
 
+#ifndef GDK_IS_WIN32_DISPLAY 
+#define GDK_IS_WIN32_DISPLAY(display) (FALSE)
+#endif
+
+
+#else
+
+#ifndef GDK_IS_X11_DISPLAY 
+#define GDK_IS_X11_DISPLAY(display) (FALSE)
+#endif
+
+#endif // GDK_WINDOWING_X11
+
 #endif // GUI_GTK
 
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -141,6 +187,7 @@ typedef int lives_pgid_t;
 #define PLUGIN_COMPOUND_DIR "/share/lives/plugins/"
 #define PLUGIN_EXEC_DIR "/lives/plugins/"
 #define ICON_DIR "/share/lives/icons/"
+#define DESKTOP_ICON_DIR "/share/app-install/icons/"
 #define DATA_DIR "/share/lives/"
 #define LIVES_CONFIG_DIR ".lives-dir/"
 #define LIVES_TMP_NAME "livestmp"
@@ -188,6 +235,9 @@ typedef int lives_pgid_t;
 /// maximum fps we will allow (gdouble)
 #define FPS_MAX 200.
 
+#define MAX_FRAME_WIDTH 100000.
+#define MAX_FRAME_HEIGHT 100000.
+
 #define ENABLE_DVD_GRAB
 
 #define FP_BITS 16 /// max fp bits [apparently 16 is faster]
@@ -386,9 +436,9 @@ typedef enum {
 
 
 typedef enum {
-  IMG_TYPE_UNKNOWN=(1<<0),
-  IMG_TYPE_JPEG=(1<<1),
-  IMG_TYPE_PNG=(1<<2)
+  IMG_TYPE_UNKNOWN=0,
+  IMG_TYPE_JPEG,
+  IMG_TYPE_PNG
 } lives_image_type_t;
 
 
@@ -402,16 +452,16 @@ typedef enum {
 
 
 typedef struct {
-  gshort red;
-  gshort green;
-  gshort blue;
+  uint16_t red;
+  uint16_t green;
+  uint16_t blue;
 } lives_colRGB24_t;
 
 typedef struct {
-  gshort red;
-  gshort green;
-  gshort blue;
-  gshort alpha;
+  uint16_t red;
+  uint16_t green;
+  uint16_t blue;
+  uint16_t alpha;
 } lives_colRGBA32_t;
 
 
@@ -476,28 +526,28 @@ typedef struct {
   gint insert_end;
   gint progress_start;
   gint progress_end;
-  gboolean changed;
+  boolean changed;
   GtkWidget *menuentry;
-  gboolean orig_file_name;
-  gboolean was_renamed;
-  gboolean is_untitled;
+  boolean orig_file_name;
+  boolean was_renamed;
+  boolean is_untitled;
   gdouble pb_fps;
   gdouble freeze_fps;
-  gboolean play_paused;
+  boolean play_paused;
   
   //opening/restoring status
-  gboolean opening;
-  gboolean opening_audio;
-  gboolean opening_only_audio;
-  gboolean opening_loc;
-  gboolean restoring;
-  gboolean is_loaded;  ///< should we continue loading if we come back to this clip
+  boolean opening;
+  boolean opening_audio;
+  boolean opening_only_audio;
+  boolean opening_loc;
+  boolean restoring;
+  boolean is_loaded;  ///< should we continue loading if we come back to this clip
 
   /// don't show preview/pause buttons on processing
-  gboolean nopreview;
+  boolean nopreview;
 
   /// don't show the 'keep' button - e.g. for operations which resize frames
-  gboolean nokeep;
+  boolean nokeep;
 
   // various times; total time is calculated as the gint64est of video, laudio and raudio
   gdouble total_time;
@@ -533,8 +583,8 @@ typedef struct {
   gint undo_end;
   gchar undo_text[32];
   gchar redo_text[32];
-  gboolean undoable;
-  gboolean redoable;
+  boolean undoable;
+  boolean redoable;
 
   // used for storing undo values
   gint undo1_int;
@@ -544,9 +594,9 @@ typedef struct {
   guint undo1_uint;
   gdouble undo1_dbl;
   gdouble undo2_dbl;
-  gboolean undo1_boolean;
-  gboolean undo2_boolean;
-  gboolean undo3_boolean;
+  boolean undo1_boolean;
+  boolean undo2_boolean;
+  boolean undo3_boolean;
 
   gint undo_arate; ///< audio playback rate
   guint undo_signed_endian;
@@ -572,7 +622,7 @@ typedef struct {
 
 #define IMG_BUFF_SIZE 4096 ///< chunk size for reading images
 
-  gboolean ratio_fps; ///< if the fps was set by a ratio
+  boolean ratio_fps; ///< if the fps was set by a ratio
 
   int64_t aseek_pos; ///< audio seek posn. (bytes) for when we switch clips
 
@@ -581,7 +631,7 @@ typedef struct {
   gchar mime_type[256];
 
 
-  gboolean deinterlace; ///< auto deinterlace
+  boolean deinterlace; ///< auto deinterlace
 
   lives_image_type_t img_type;
 
@@ -596,11 +646,14 @@ typedef struct {
   gchar *op_dir;
   guint64 op_ds_warn_level; ///< current disk space warning level for any output directory
 
-  gboolean no_proc_sys_errors; ///< skip system error dialogs in processing
-  gboolean no_proc_read_errors; ///< skip read error dialogs in processing
-  gboolean no_proc_write_errors; ///< skip write error dialogs in processing
+  boolean no_proc_sys_errors; ///< skip system error dialogs in processing
+  boolean no_proc_read_errors; ///< skip read error dialogs in processing
+  boolean no_proc_write_errors; ///< skip write error dialogs in processing
 
-  gboolean keep_without_preview; ///< allow keep, even when nopreview is set - TODO use only nopreview and nokeep
+  boolean keep_without_preview; ///< allow keep, even when nopreview is set - TODO use only nopreview and nokeep
+
+  lives_painter_surface_t *laudio_drawable;
+  lives_painter_surface_t *raudio_drawable;
 
   // TODO - change to lives_clip_t
 } file;
@@ -609,31 +662,30 @@ typedef struct {
 
 typedef struct {
   // the following can be assumed TRUE, they are checked on startup
-  gboolean has_smogrify;
-  gboolean smog_version_correct;
-  gboolean can_read_from_config;
-  gboolean can_write_to_config;
-  gboolean can_write_to_tmp;
-  gboolean can_write_to_tempdir;
+  boolean has_smogrify;
+  boolean smog_version_correct;
+  boolean can_read_from_config;
+  boolean can_write_to_config;
+  boolean can_write_to_tmp;
+  boolean can_write_to_tempdir;
 
   // the following may need checking before use
-  gboolean has_xmms;
-  gboolean has_dvgrab;
-  gboolean has_sox_play;
-  gboolean has_sox_sox;
-  gboolean has_autolives;
-  gboolean has_mplayer;
-  gboolean has_convert;
-  gboolean has_composite;
-  gboolean has_identify;
-  gboolean has_cdda2wav;
-  gboolean has_midistartstop;
-  gboolean has_jackd;
-  gboolean has_pulse_audio;
-  gboolean has_xwininfo;
-  gboolean has_gdb;
-  gboolean has_gconftool_2;
-  gboolean has_xdg_screensaver;
+  boolean has_dvgrab;
+  boolean has_sox_play;
+  boolean has_sox_sox;
+  boolean has_autolives;
+  boolean has_mplayer;
+  boolean has_convert;
+  boolean has_composite;
+  boolean has_identify;
+  boolean has_cdda2wav;
+  boolean has_midistartstop;
+  boolean has_jackd;
+  boolean has_pulse_audio;
+  boolean has_xwininfo;
+  boolean has_gdb;
+  boolean has_gconftool_2;
+  boolean has_xdg_screensaver;
 
   /// home directory - default location for config file - locale encoding
   gchar home_dir[PATH_MAX];
@@ -647,9 +699,9 @@ typedef struct {
   gchar startup_msg[256];
 
   // plugins
-  gboolean has_encoder_plugins;
+  boolean has_encoder_plugins;
 
-  gboolean has_python;
+  boolean has_python;
   guint64 python_version;
 
   gshort cpu_bits;
@@ -658,7 +710,7 @@ typedef struct {
   gchar *myname_full;
   gchar *myname;
 
-  gboolean has_stderr;
+  boolean has_stderr;
 
   gint nmonitors;
 
@@ -709,7 +761,7 @@ extern capability *capable;
 #endif // ifndef PRI64d
 
 
-// common defs for mainwindow
+// common defs for mainwindow (retain this order)
 #include "plugins.h"
 #include "colourspace.h"
 #include "paramspecial.h"
@@ -767,26 +819,30 @@ void make_play_window(void);
 void resize_play_window (void);
 void kill_play_window (void);
 void make_preview_box (void);
+void play_window_set_title(void);
 void add_to_playframe (void);
-GtkWidget* create_cdtrack_dialog (gint type, gpointer user_data);
+GtkWidget* create_cdtrack_dialog (int type, gpointer user_data);
 GtkTextView *create_output_textview(void);
-gchar *choose_file(gchar *dir, gchar *fname, gchar **filt, GtkFileChooserAction act, const char *title, GtkWidget *extra);
-void choose_file_with_preview (gchar *dir, const gchar *title, gint preview_type);
+gchar *choose_file(gchar *dir, gchar *fname, gchar **filt, lives_file_chooser_action_t act, const char *title, GtkWidget *extra);
+void choose_file_with_preview (gchar *dir, const gchar *title, int preview_type);
 void add_suffix_check(GtkBox *box, const gchar *ext);
 
 
 // dialogs.c
-gboolean do_progress_dialog(gboolean visible, gboolean cancellable, const gchar *text);
-gboolean do_warning_dialog(const gchar *text);
-gboolean do_warning_dialog_with_check(const gchar *text, gint warn_mask_number);
-gboolean do_warning_dialog_with_check_transient(const gchar *text, gint warn_mask_number, GtkWindow *transient);
-gboolean do_yesno_dialog(const gchar *text) WARN_UNUSED;
+boolean do_progress_dialog(boolean visible, boolean cancellable, const gchar *text);
+boolean do_warning_dialog(const gchar *text);
+boolean do_warning_dialog_with_check(const gchar *text, int warn_mask_number);
+boolean do_warning_dialog_with_check_transient(const gchar *text, int warn_mask_number, GtkWindow *transient);
+boolean do_yesno_dialog(const gchar *text) WARN_UNUSED;
 int do_abort_cancel_retry_dialog(const gchar *text, GtkWindow *transient) WARN_UNUSED;
 void do_error_dialog(const gchar *text);
-void do_error_dialog_with_check(const gchar *text, gint warn_mask_number);
+void do_info_dialog(const gchar *text);
+void do_error_dialog_with_check(const gchar *text, int warn_mask_number);
 void do_blocking_error_dialog(const gchar *text);
-void do_error_dialog_with_check_transient(const gchar *text, gboolean is_blocking,gint warn_mask_number, 
+void do_blocking_info_dialog(const gchar *text);
+void do_error_dialog_with_check_transient(const gchar *text, boolean is_blocking, int warn_mask_number, 
 					  GtkWindow *transient);
+void do_info_dialog_with_transient(const gchar *text, boolean is_blocking, GtkWindow *transient);
 
 
 void do_system_failed_error(const char *com, int retval, const char *addinfo);
@@ -794,41 +850,41 @@ int do_write_failed_error_s_with_retry(const gchar *fname, const gchar *errtext,
 void do_write_failed_error_s(const char *filename, const char *addinfo);
 int do_read_failed_error_s_with_retry(const gchar *fname, const gchar *errtext, GtkWindow *transient) WARN_UNUSED;
 void do_read_failed_error_s(const char *filename, const char *addinfo);
-gboolean do_header_write_error(int clip);
+boolean do_header_write_error(int clip);
 int do_header_read_error_with_retry(int clip) WARN_UNUSED;
 int do_header_missing_detail_error(int clip, lives_clip_details_t detail) WARN_UNUSED;
 void do_chdir_failed_error(const char *dir);
 void handle_backend_errors(void);
-gboolean check_backend_return(file *sfile);
+boolean check_backend_return(file *sfile);
 
 /** warn about disk space */
 gchar *ds_critical_msg(const gchar *dir, guint64 dsval);
 gchar *ds_warning_msg(const gchar *dir, guint64 dsval, guint64 cwarn, guint64 nwarn);
-gboolean check_storage_space(file *sfile, gboolean is_processing);
+boolean check_storage_space(file *sfile, boolean is_processing);
 
 gchar *get_upd_msg(void);
 gchar *get_new_install_msg(void);
 
-gboolean ask_permission_dialog(int what);
-gboolean do_abort_check(void);
-void add_warn_check (GtkBox *box, gint warn_mask_number);
+boolean ask_permission_dialog(int what);
+boolean do_abort_check(void);
+void add_warn_check (GtkBox *box, int warn_mask_number);
 void do_memory_error_dialog (void);
 void too_many_files(void);
 void tempdir_warning (void);
 void do_audio_import_error(void);
 void do_mt_backup_space_error(lives_mt *, gint memreq_mb);
 
-gboolean do_clipboard_fps_warning(void);
+boolean do_clipboard_fps_warning(void);
 void perf_mem_warning(void);
 void do_dvgrab_error(void);
-gboolean do_comments_dialog (file *sfile, gchar *filename);
-gboolean do_auto_dialog(const gchar *text, gint type);
+boolean do_comments_dialog (file *sfile, gchar *filename);
+boolean do_auto_dialog(const gchar *text, int type);
 void do_encoder_acodec_error (void);
 void do_encoder_sox_error(void);
-gboolean rdet_suggest_values (gint width, gint height, gdouble fps, gint fps_num, gint fps_denom, gint arate, 
-			      gint asigned, gboolean swap_endian, gboolean anr, gboolean ignore_fps);
-gboolean do_encoder_restrict_dialog (gint width, gint height, gdouble fps, gint fps_num, gint fps_denom, 
-				     gint arate, gint asigned, gboolean swap_endian, gboolean anr, gboolean save_all);
+boolean rdet_suggest_values (int width, int height, double fps, int fps_num, int fps_denom, int arate, 
+			     int asigned, boolean swap_endian, boolean anr, boolean ignore_fps);
+boolean do_encoder_restrict_dialog (int width, int height, double fps, int fps_num, int fps_denom, 
+				    int arate, int asigned, boolean swap_endian, boolean anr, boolean save_all);
 void do_keys_window (void);
 void do_mt_keys_window (void);
 void do_messages_window (void);
@@ -840,26 +896,26 @@ void do_rendered_fx_dialog(void);
 void do_layout_scrap_file_error(void);
 void do_layout_ascrap_file_error(void);
 void do_set_load_lmap_error(void);
-gboolean do_set_duplicate_warning (const gchar *new_set);
-gboolean do_set_rename_old_layouts_warning(const gchar *new_set);
-gboolean do_layout_alter_frames_warning(void);
-gboolean do_layout_alter_audio_warning(void);
-gboolean do_yuv4m_open_warning(void);
+boolean do_set_duplicate_warning (const gchar *new_set);
+boolean do_set_rename_old_layouts_warning(const gchar *new_set);
+boolean do_layout_alter_frames_warning(void);
+boolean do_layout_alter_audio_warning(void);
+boolean do_yuv4m_open_warning(void);
 void do_mt_undo_mem_error(void);
 void do_mt_undo_buf_error(void);
-void do_mt_set_mem_error(gboolean has_mt, gboolean trans);
-void do_mt_audchan_error(gint warn_mask);
+void do_mt_set_mem_error(boolean has_mt, boolean trans);
+void do_mt_audchan_error(int warn_mask);
 void do_mt_no_audchan_error(void);
-void do_mt_no_jack_error(gint warn_mask);
-gboolean do_mt_rect_prompt(void);
+void do_mt_no_jack_error(int warn_mask);
+boolean do_mt_rect_prompt(void);
 void do_audrate_error_dialog(void);
-gboolean do_event_list_warning(void);
+boolean do_event_list_warning(void);
 void do_nojack_rec_error(void);
 void do_vpp_palette_error (void);
 void do_vpp_fps_error (void);
 void do_decoder_palette_error (void);
 void do_rmem_max_error (gint size);
-gboolean do_original_lost_warning(const gchar *fname);
+boolean do_original_lost_warning(const gchar *fname);
 void do_no_decoder_error(const gchar *fname);
 void do_jack_noopen_warn(void);
 void do_jack_noopen_warn2(void);
@@ -867,16 +923,17 @@ void do_jack_noopen_warn3(void);
 void do_jack_noopen_warn4(void);
 void do_file_perm_error(const gchar *file_name);
 void do_dir_perm_error(const gchar *dir_name);
+void do_dir_perm_access_error(const gchar *dir_name);
 void do_encoder_img_ftm_error(render_details *rdet);
 void do_after_crash_warning (void);
 void do_bad_layout_error(void);
 void do_card_in_use_error(void);
 void do_dev_busy_error(const gchar *devstr);
-gboolean do_existing_subs_warning(void);
+boolean do_existing_subs_warning(void);
 void do_invalid_subs_error(void);
-gboolean do_erase_subs_warning(void);
-gboolean do_sub_type_warning(const gchar *ext, const gchar *type_ext);
-gboolean do_move_tmpdir_dialog(void);
+boolean do_erase_subs_warning(void);
+boolean do_sub_type_warning(const gchar *ext, const gchar *type_ext);
+boolean do_move_tmpdir_dialog(void);
 void do_set_locked_warning (const gchar *setname);
 void do_no_in_vdevs_error(void);
 void do_locked_in_vdevs_error(void);
@@ -887,8 +944,8 @@ void do_autolives_needs_clips_error(void);
 void do_pulse_lost_conn_error(void);
 void do_jack_lost_conn_error(void);
 
-gboolean process_one (gboolean visible);
-void do_threaded_dialog(gchar *translated_text, gboolean has_cancel);
+boolean process_one (boolean visible);
+void do_threaded_dialog(gchar *translated_text, boolean has_cancel);
 void end_threaded_dialog(void);
 void threaded_dialog_spin (void);
 void response_ok (GtkButton *button, gpointer user_data);
@@ -907,69 +964,78 @@ void d_print_file_error_failed(void);
 void do_text_window (const gchar *title, const gchar *text);
 
 // saveplay.c
-gboolean add_file_info(const gchar *check_handle, gboolean aud_only);
-gboolean save_file_comments (int fileno);
+boolean read_file_details(const gchar *file_name, boolean only_check_for_audio);
+boolean add_file_info(const gchar *check_handle, boolean aud_only);
+boolean save_file_comments (int fileno);
 void reget_afilesize (int fileno);
-void deduce_file(const gchar *filename, gdouble start_time, gint end);
+void deduce_file(const gchar *filename, double start_time, int end);
 void open_file (const gchar *filename);
-void open_file_sel(const gchar *file_name,gdouble start_time, gint frames);
+void open_file_sel(const gchar *file_name, double start_time, int frames);
 void open_fw_device (void);
-gboolean get_new_handle(gint index, const gchar *name);
-gboolean get_temp_handle(gint index, gboolean create);
-gboolean get_handle_from_info_file(gint index);
+boolean get_new_handle(int index, const gchar *name);
+boolean get_temp_handle(int index, boolean create);
+boolean get_handle_from_info_file(int index);
 void create_cfile(void);
 void save_file (int clip, int start, int end, const char *filename);
 void play_file (void);
 void save_frame (GtkMenuItem *menuitem, gpointer user_data);
-gboolean save_frame_inner(gint clip, gint frame, const gchar *file_name, gint width, gint height, gboolean auto_overwrite);
+boolean save_frame_inner(int clip, int frame, const gchar *file_name, int width, int height, boolean from_osc);
 void wait_for_stop (const gchar *stop_command);
-gboolean save_clip_values(gint which_file);
+boolean save_clip_values(int which_file);
 void add_to_recovery_file (const gchar *handle);
 void rewrite_recovery_file(void);
-gboolean check_for_recovery_files (gboolean auto_recover);
-void recover_layout_map(gint numclips);
+boolean check_for_recovery_files (boolean auto_recover);
+void recover_layout_map(int numclips);
 const gchar *get_deinterlace_string(void);
 
 // saveplay.c backup
 void backup_file(int clip, int start, int end, const gchar *filename);
 gint save_event_frames(void);
-gboolean write_headers (file *file);
+boolean write_headers (file *file);
 
 // saveplay.c restore
 void restore_file(const gchar *filename);
-gboolean read_headers(const gchar *file_name);
+boolean read_headers(const gchar *file_name);
 
 // saveplay.c sets
 void open_set_file (const gchar *set_name, gint clipnum);
 
 
 // saveplay.c scrap file
-gboolean open_scrap_file (void);
-gboolean open_ascrap_file (void);
-gint save_to_scrap_file (weed_plant_t *layer);
-gboolean load_from_scrap_file(weed_plant_t *layer, int frame);
+boolean open_scrap_file (void);
+boolean open_ascrap_file (void);
+int save_to_scrap_file (weed_plant_t *layer);
+boolean load_from_scrap_file(weed_plant_t *layer, int frame);
 void close_ascrap_file (void);
 void close_scrap_file (void);
 
 
 // main.c
+typedef void (*SignalHandlerPointer)(int);
+
+void set_signal_handlers(SignalHandlerPointer sigfunc);
 void catch_sigint(int signum);
-gboolean startup_message_fatal(const gchar *msg);
-gboolean startup_message_nonfatal(const gchar *msg);
-gboolean startup_message_nonfatal_dismissable(const gchar *msg, gint warning_mask);
+void defer_sigint(int signum);
+boolean startup_message_fatal(const gchar *msg);
+boolean startup_message_nonfatal(const gchar *msg);
+boolean startup_message_info(const gchar *msg);
+boolean startup_message_nonfatal_dismissable(const gchar *msg, gint warning_mask);
 capability *get_capabilities(void);
 void get_monitors(void);
+void set_ce_frame_from_pixbuf(GtkImage *image, GdkPixbuf *pixbuf, lives_painter_t *);
 void load_start_image(gint frame);
 void load_end_image(gint frame);
-void load_preview_image(gboolean update_always);
+void load_preview_image(boolean update_always);
 
-gboolean pull_frame(weed_plant_t *layer, const gchar *image_ext, weed_timecode_t tc);
-gboolean pull_frame_at_size (weed_plant_t *layer, const gchar *image_ext, weed_timecode_t tc, 
+boolean pull_frame(weed_plant_t *layer, const gchar *image_ext, weed_timecode_t tc);
+boolean pull_frame_at_size (weed_plant_t *layer, const gchar *image_ext, weed_timecode_t tc, 
 			     int width, int height, int target_palette);
 LiVESPixbuf *pull_lives_pixbuf_at_size(int clip, int frame, const char *image_ext, weed_timecode_t tc, 
 				       int width, int height, LiVESInterpType interp);
+LiVESPixbuf *pull_lives_pixbuf(int clip, int frame, const char *image_ext, weed_timecode_t tc);
+
 GError * lives_pixbuf_save(GdkPixbuf *pixbuf, gchar *fname, lives_image_type_t imgtype, 
-			   int quality, gboolean do_chmod, GError **gerrorptr);
+			   int quality, boolean do_chmod, GError **gerrorptr);
 
 void load_frame_image(gint frame);
 void sensitize(void);
@@ -981,13 +1047,11 @@ void switch_to_file(gint old_file, gint new_file);
 void do_quick_switch (gint new_file);
 void switch_audio_clip(gint new_file, boolean activate);
 void resize (gdouble scale);
-gboolean read_file_details(const gchar *file_name, gboolean only_check_for_audio);
 void do_start_messages(void);
 void set_palette_colours (void);
 void set_main_title(const gchar *filename, gint or_untitled_number);
 void set_record (void);
 
-//gui.c
 //gui.c
 void  create_LiVES (void);
 void enable_record (void);
@@ -1001,18 +1065,23 @@ void unblock_expose (void);
 void frame_size_update(void);
 void splash_init(void);
 void splash_end(void);
-void splash_msg(const gchar *msg, gdouble pct);
+void splash_msg(const gchar *msg, double pct);
 void add_message_scroller(GtkWidget *conter);
-
-
+void resize_widgets_for_monitor(boolean get_play_times);
+#if GTK_CHECK_VERSION(3,0,0)
+void calibrate_sepwin_size(void);
+boolean expose_pim (GtkWidget *widget, lives_painter_t *cr, gpointer user_data);
+boolean expose_sim (GtkWidget *widget, lives_painter_t *cr, gpointer user_data);
+boolean expose_eim (GtkWidget *widget, lives_painter_t *cr, gpointer user_data);
+#endif
 // system calls in utils.c
-int lives_system(const char *com, gboolean allow_error);
+int lives_system(const char *com, boolean allow_error);
 lives_pid_t lives_fork(const char *com);
-ssize_t lives_write(int fd, const void *buf, size_t count, gboolean allow_fail);
-ssize_t lives_write_le(int fd, const void *buf, size_t count, gboolean allow_fail);
-ssize_t lives_read(int fd, void *buf, size_t count, gboolean allow_less);
-ssize_t lives_read_le(int fd, void *buf, size_t count, gboolean allow_less);
-int lives_chdir(const char *path, gboolean allow_fail);
+ssize_t lives_write(int fd, const void *buf, size_t count, boolean allow_fail);
+ssize_t lives_write_le(int fd, const void *buf, size_t count, boolean allow_fail);
+ssize_t lives_read(int fd, void *buf, size_t count, boolean allow_less);
+ssize_t lives_read_le(int fd, void *buf, size_t count, boolean allow_less);
+int lives_chdir(const char *path, boolean allow_fail);
 int lives_fputs(const char *s, FILE *stream);
 char *lives_fgets(char *s, int size, FILE *stream);
 pid_t lives_getpid(void);
@@ -1022,8 +1091,8 @@ void lives_freep(void **ptr);
 void lives_free(gpointer ptr);
 void lives_free_with_check(gpointer ptr);
 #ifdef IS_MINGW
-gboolean lives_win32_suspend_resume_process(DWORD pid, gboolean suspend);
-gboolean lives_win32_kill_subprocesses(DWORD pid, gboolean kill_parent);
+boolean lives_win32_suspend_resume_process(DWORD pid, boolean suspend);
+boolean lives_win32_kill_subprocesses(DWORD pid, boolean kill_parent);
 int lives_win32_get_num_logical_cpus(void);
 #endif
 int lives_kill(lives_pid_t pid, int sig);
@@ -1042,79 +1111,65 @@ uint64_t lives_10pow(int pow);
 int get_approx_ln(guint val);
 
 int64_t lives_get_current_ticks(void);
-gboolean lives_alarm_get(int alarm_handle);
+boolean lives_alarm_get(int alarm_handle);
 int lives_alarm_set(int64_t ticks);
 void lives_alarm_clear(int alarm_handle);
 lives_storage_status_t get_storage_status(const char *dir, guint64 warn_level, guint64 *dsval);
 gchar *lives_format_storage_space_string(guint64 space);
 
 
-gint myround(gdouble n);
+int myround(double n);
 void get_dirname(gchar *filename);
 gchar *get_dir(const gchar *filename);
 void get_basename(gchar *filename);
-void get_filename(gchar *filename, gboolean strip_dir);
+void get_filename(gchar *filename, boolean strip_dir);
 gchar *get_extension(const gchar *filename);
-guint64 get_version_hash(const gchar *exe, const gchar *sep, int piece);
+uint64_t get_version_hash(const gchar *exe, const gchar *sep, int piece);
+uint64_t make_version_hash(const char *ver);
 void d_print(const gchar *text);
 void init_clipboard(void);
-gboolean cache_file_contents(const gchar *filename);
+boolean cache_file_contents(const gchar *filename);
 gchar *get_val_from_cached_list(const gchar *key, size_t maxlen);
-void get_pref(const gchar *key, gchar *val, gint maxlen);
-void get_pref_utf8(const gchar *key, gchar *val, gint maxlen);
-void get_pref_default(const gchar *key, gchar *val, gint maxlen);
-gboolean get_boolean_pref(const gchar *key);
-gdouble get_double_pref(const gchar *key);
-gint get_int_pref(const gchar *key);
-GList *get_list_pref(const gchar *key);
-void get_location(const gchar *exe, gchar *val, gint maxlen);
-void set_pref (const gchar *key, const gchar *value);
-void delete_pref (const gchar *key);
-void set_boolean_pref(const gchar *key, gboolean value);
-void set_double_pref(const gchar *key, gdouble value);
-void set_int_pref(const gchar *key, gint value);
-void set_int64_pref(const gchar *key, gint64 value);
-void set_list_pref(const char *key, GList *values);
-gboolean apply_prefs(gboolean skip_warnings);
-void save_future_prefs(void);
-void set_menu_text(GtkWidget *menu, const gchar *text, gboolean use_mnemonic);
+
+void get_location(const gchar *exe, gchar *val, int maxlen);
+
+void set_menu_text(GtkWidget *menu, const gchar *text, boolean use_mnemonic);
 void get_menu_text(GtkWidget *menu, gchar *text);
 void get_menu_text_long(GtkWidget *menuitem, gchar *text);
 void reset_clip_menu (void);
 void get_play_times(void);
 void get_total_time (file *file);
-guint get_signed_endian (gboolean is_signed, gboolean little_endian);
+guint get_signed_endian (boolean is_signed, boolean little_endian);
 void fullscreen_internal(void);
-void set_alwaysontop(GtkWidget *window, gboolean ontop); ///< TODO - use for playwin
 void colour_equal(GdkColor *c1, const GdkColor *c2);
 void switch_to_int_player(void);
 void switch_to_mplayer(void);
-void switch_aud_to_sox(gboolean set_pref);
-gboolean switch_aud_to_jack(void);
-gboolean switch_aud_to_pulse(void);
-void switch_aud_to_mplayer(gboolean set_pref);
-void prepare_to_play_foreign(void);
-gboolean after_foreign_play(void);
-gboolean check_file(const gchar *file_name, gboolean check_exists);  ///< check if file exists
-gboolean check_dir_access (const gchar *dir);
+void switch_aud_to_sox(boolean set_pref);
+boolean switch_aud_to_jack(void);
+boolean switch_aud_to_pulse(void);
+void switch_aud_to_mplayer(boolean set_pref);
+boolean prepare_to_play_foreign(void);
+boolean after_foreign_play(void);
+boolean check_file(const gchar *file_name, boolean check_exists);  ///< check if file exists
+boolean check_dir_access (const gchar *dir);
 uint64_t get_file_size(int fd);
 uint64_t sget_file_size(const gchar *name);
 uint64_t get_fs_free(const char *dir);
-gboolean is_writeable_dir(const char *dir);
-gboolean ensure_isdir(gchar *fname);
+boolean is_writeable_dir(const char *dir);
+boolean ensure_isdir(gchar *fname);
 gchar *ensure_extension(const gchar *fname, const gchar *ext) WARN_UNUSED;
-gboolean check_dev_busy(gchar *devstr);
+boolean check_dev_busy(gchar *devstr);
 void activate_url_inner(const gchar *link);
 void activate_url (GtkAboutDialog *about, const gchar *link, gpointer data);
 void show_manual_section (const gchar *lang, const gchar *section);
 
-gdouble calc_time_from_frame (gint clip, gint frame);
-gint calc_frame_from_time (gint filenum, gdouble time);  ///< nearest frame start
-gint calc_frame_from_time2 (gint filenum, gdouble time); ///< nearest frame end
-gint calc_frame_from_time3 (gint filenum, gdouble time); ///< nearest frame mid
+double calc_time_from_frame (int clip, int frame);
+gint calc_frame_from_time (int filenum, double time);  ///< nearest frame start
+gint calc_frame_from_time2 (int filenum, double time); ///< nearest frame end
+gint calc_frame_from_time3 (int filenum, double time); ///< nearest frame mid
 
-gboolean check_for_ratio_fps (gdouble fps);
-gdouble get_ratio_fps(const gchar *string);
+boolean check_for_ratio_fps (double fps);
+double get_ratio_fps(const gchar *string);
 void calc_maxspect(gint rwidth, gint rheight, gint *cwidth, gint *cheight);
 
 gchar *remove_trailing_zeroes(gdouble val);
@@ -1131,8 +1186,9 @@ gboolean get_clip_value(int which, lives_clip_details_t, void *retval, size_t ma
 void save_clip_value(int which, lives_clip_details_t, void *val);
 gboolean check_frame_count(gint idx);
 void get_frame_count(gint idx);
+void get_frames_sizes(int fileno, int frame_to_test);
 gint count_resampled_frames (gint in_frames, gdouble orig_fps, gdouble resampled_fps);
-gboolean int_array_contains_value(int *array, int num_elems, int value);
+boolean int_array_contains_value(int *array, int num_elems, int value);
 gboolean check_for_lock_file(const gchar *set_name, gint type);
 void g_list_free_strings(GList *list);
 
@@ -1145,12 +1201,12 @@ void zero_spinbuttons (void);
 void draw_little_bars (gdouble ptrtime);
 void set_sel_label (GtkWidget *label);
 void clear_mainw_msg (void);
-gint get_token_count (const gchar *string, int delim);
+int get_token_count (const gchar *string, int delim);
 LiVESPixbuf *lives_pixbuf_new_blank(int width, int height, int palette);
 gchar *g_strappend (gchar *string, gint len, const gchar *newbit);
 GList *g_list_append_unique(GList *xlist, const gchar *add);
 void find_when_to_stop (void);
-gint calc_new_playback_position(gint fileno, gint64 otc, gint64 *ntc);
+int calc_new_playback_position(int fileno, uint64_t otc, uint64_t *ntc);
 void calc_aframeno(gint fileno);
 void minimise_aspect_delta (gdouble allowed_aspect,gint hblock,gint vblock,gint hsize,gint vsize,gint *width,gint *height);
 LiVESInterpType get_interp_value(gshort quality);
@@ -1169,6 +1225,8 @@ gchar *insert_newlines(const gchar *text, int maxwidth);
 gint hextodec (const gchar *string);
 gint get_hex_digit (const gchar *c);
 
+const char *get_image_ext_for_type(lives_image_type_t imgtype);
+
 guint32 fastrand(void);
 void fastsrand(guint32 seed);
 
@@ -1178,7 +1236,7 @@ lives_cancel_t check_for_bad_ffmpeg(void);
 
 // plugins.c
 GList *get_external_window_hints(lives_rfx_t *rfx);
-gboolean check_encoder_restrictions (gboolean get_extension, gboolean user_audio, gboolean save_all);
+gboolean check_encoder_restrictions (boolean get_extension, boolean user_audio, boolean save_all);
 
 //callbacks.c
 void lives_exit (void);
@@ -1190,13 +1248,30 @@ void on_cancel_keep_button_clicked (GtkButton *, gpointer user_data);
 void on_cleardisk_activate (GtkWidget *, gpointer user_data);
 void on_cleardisk_advanced_clicked (GtkWidget *, gpointer user_data);
 void popup_lmap_errors(GtkMenuItem *, gpointer);
+void on_filesel_button_clicked (GtkButton *button, gpointer user_data);
+
+
+//preferences.c
+void get_pref(const gchar *key, gchar *val, int maxlen);
+void get_pref_utf8(const gchar *key, gchar *val, int maxlen);
+void get_pref_default(const gchar *key, gchar *val, int maxlen);
+boolean get_boolean_pref(const gchar *key);
+double get_double_pref(const gchar *key);
+int get_int_pref(const gchar *key);
+GList *get_list_pref(const gchar *key);
+void set_pref (const gchar *key, const gchar *value);
+void delete_pref (const gchar *key);
+void set_boolean_pref(const gchar *key, boolean value);
+void set_double_pref(const gchar *key, double value);
+void set_int_pref(const gchar *key, int value);
+void set_int64_pref(const gchar *key, int64_t value);
+void set_list_pref(const char *key, GList *values);
+boolean apply_prefs(boolean skip_warnings);
+void save_future_prefs(void);
 
 
 // paramspecial.c
-boolean mt_framedraw(lives_mt *, GdkPixbuf *);
-
-// paramwindow.c
-void add_fill_to_box (GtkBox *);
+LiVESPixbuf *mt_framedraw(lives_mt *, LiVESPixbuf *);
 
 // rte_window.c
 void refresh_rte_window (void);
