@@ -1,6 +1,6 @@
 // mainwindow.h
 // LiVES (lives-exe)
-// (c) G. Finch <salsaman@xs4all.nl,salsaman@gmail.com> 2003 - 2013
+// (c) G. Finch <salsaman@gmail.com> 2003 - 2013
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -30,21 +30,62 @@
 #define U_SECL (gint64)100000000
 #define U_SEC_RATIO (U_SECL/1000000) ///< how many U_SECs (ticks) in a microsecond [default 100]
 
-// parameters for resizing the image frames, and for capture
-// TODO - make prefs
-#define V_RESIZE_ADJUST 36
-#define H_RESIZE_ADJUST 22
 
-// sepwin/screen size safety margins in pixels
-#define DSIZE_SAFETY_H 100
-#define DSIZE_SAFETY_V 100
+
+/////// GUI related constants /////////////////////////////////////////////////////////
+
+// parameters for resizing the image frames, and for capture
+#define V_RESIZE_ADJUST 36
+#define H_RESIZE_ADJUST 24
+
+#define CE_FRAME_HSPACE ((int)(320.*widget_opts.scale))
+
+#define MIN_SEPWIN_WIDTH 600
+#define MIN_SEPWIN_HEIGHT 36
+
+/// sepwin/screen size safety margins in pixels
+#define SCR_HEIGHT_SAFETY ((int)(100.*widget_opts.scale))
+#define SCR_WIDTH_SAFETY ((int)(100.*widget_opts.scale))
 
 /// default size for generators
 #define DEF_GEN_WIDTH 640
 #define DEF_GEN_HEIGHT 480
 
-// height of preview widgets in sepwin
-#define PREVIEW_BOX_HT 100
+/// height of preview widgets in sepwin
+#define PREVIEW_BOX_HT ((int)(100.*widget_opts.scale))
+
+/// height of msg area
+#define MSG_AREA_HEIGHT ((int)(50.*widget_opts.scale))
+
+/// clip editor hrule height
+#define CE_HRULE_HEIGHT ((int)(20.*widget_opts.scale))
+
+/// clip edit vid/aud bar height
+#define CE_VIDBAR_HEIGHT ((int)(10.*widget_opts.scale))
+
+// a few GUI specific settings
+#define DEFAULT_FRAME_HSIZE 320
+#define DEFAULT_FRAME_VSIZE 200
+
+#define MAIN_SPIN_SPACER ((int)52.*widget_opts.scale) ///< pixel spacing for start/end spins for clip and multitrack editors
+
+/// blank label to show so our message dialogs are not too small
+#define PROCW_STRETCHER "                                                                                                                            "
+
+#define ENC_DETAILS_WIN_H ((int)(600.*widget_opts.scale)) ///< horizontal size in pixels of the encoder output window
+#define ENC_DETAILS_WIN_V ((int)(200.*widget_opts.scale)) ///< vertical size in pixels of the encoder output window
+
+#define MAX_MSG_WIDTH_CHARS ((int)(100.*widget_opts.scale)) ///< max width of text on warning/error labels
+
+/// size of the fx dialog windows scrollwindow
+#define RFX_WINSIZE_H ((int)(mainw->scr_width>1024?(820.*widget_opts.scale):600))
+#define RFX_WINSIZE_V ((int)(480.*widget_opts.scale))
+
+#define RFX_TEXT_SCROLL_HEIGHT ((int)(80.*widget_opts.scale)) ///< height of textview scrolled window
+
+#define DEF_BUTTON_WIDTH ((int)(80.*widget_opts.scale))
+
+////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 /// number of function keys
 #define FN_KEYS 12
@@ -64,6 +105,7 @@
 
 #define MAX_FX_THREADS 65536
 
+#define LIVES_DCLICK_TIME 400 ///< double click time (milliseconds)
 
 /// max ext_cntl + 1
 #define MAX_EXT_CNTL 2
@@ -100,8 +142,15 @@ typedef enum {
   LIVES_DIALOG_ABORT_CANCEL_RETRY
 } lives_dialog_t;
 
+typedef enum {
+  LIVES_INFO_TYPE_INFO,
+  LIVES_INFO_TYPE_WARNING,
+  LIVES_INFO_TYPE_QUESTION,
+  LIVES_INFO_TYPE_ERROR
+} lives_info_t;
 
-// return values from abort/cancel/retry dialog and yes/no dialog
+
+/// return values from abort/cancel/retry dialog and yes/no dialog
 enum {
   LIVES_NO=0,
   LIVES_YES,
@@ -112,7 +161,7 @@ enum {
 };
 
 
-// various return conditions from rendering (multitrack or after recording)
+/// various return conditions from rendering (multitrack or after recording)
 typedef enum {
   LIVES_RENDER_ERROR_NONE=0,
   LIVES_RENDER_READY,
@@ -128,7 +177,7 @@ typedef enum {
 } lives_render_error_t;
 
 
-// disk/storage status values
+/// disk/storage status values
 typedef enum {
   LIVES_STORAGE_STATUS_UNKNOWN=0,
   LIVES_STORAGE_STATUS_NORMAL,
@@ -150,43 +199,42 @@ typedef struct {
 #define STYLE_5 1<<4 ///< drop down menu text col. in mt
 #define STYLE_6 1<<4 ///< separator col. in mt
 
-  GdkColor white;
-  GdkColor black;
-  GdkColor light_blue;
-  GdkColor light_yellow;
-  GdkColor pink;
-  GdkColor light_red;
-  GdkColor dark_red;
-  GdkColor light_green;
-  GdkColor grey20;
-  GdkColor grey25;
-  GdkColor grey45;
-  GdkColor grey60;
-  GdkColor dark_orange;
-  GdkColor fade_colour;
-  GdkColor normal_back;
-  GdkColor normal_fore;
+  LiVESWidgetColor white;
+  LiVESWidgetColor black;
+  LiVESWidgetColor light_blue;
+  LiVESWidgetColor light_yellow;
+  LiVESWidgetColor pink;
+  LiVESWidgetColor light_red;
+  LiVESWidgetColor dark_red;
+  LiVESWidgetColor light_green;
+  LiVESWidgetColor grey20;
+  LiVESWidgetColor grey25;
+  LiVESWidgetColor grey45;
+  LiVESWidgetColor grey60;
+  LiVESWidgetColor dark_orange;
+  LiVESWidgetColor fade_colour;
+  LiVESWidgetColor normal_back;
+  LiVESWidgetColor normal_fore;
 
-  GdkColor menu_and_bars;
-  GdkColor banner_fade_text;
-  GdkColor info_text;
-  GdkColor info_base;
-
-  GdkColor bm_opaque;
-  GdkColor bm_trans;
+  LiVESWidgetColor menu_and_bars;
+  LiVESWidgetColor banner_fade_text;
+  LiVESWidgetColor info_text;
+  LiVESWidgetColor info_base;
 
 } _palette;
 
-
+/// screen details
 typedef struct {
-  gint x;
-  gint y;
-  gint width;
-  gint height;
-  GdkScreen *screen;
+  int x;
+  int y;
+  int width;
+  int height;
+  LiVESXDevice *mouse_device; ///< unused for gtk+ < 3.0.0
+  LiVESXDisplay *disp;
+  LiVESXScreen *screen;
 } lives_mgeometry_t;
 
-// constant strings
+/// constant strings
 enum {
   LIVES_STRING_CONSTANT_ANY=0,
   LIVES_STRING_CONSTANT_NONE,
@@ -214,11 +262,11 @@ typedef struct {
   file *files[MAX_FILES+1]; ///< +1 for the clipboard
   gchar vid_load_dir[PATH_MAX];
   gchar vid_save_dir[PATH_MAX];
+  gchar vid_dl_dir[PATH_MAX];
   gchar audio_dir[PATH_MAX];
   gchar image_dir[PATH_MAX];
   gchar proj_load_dir[PATH_MAX];
   gchar proj_save_dir[PATH_MAX];
-  gchar xmms_dir[PATH_MAX];
   gint untitled_number;
   gint cap_number;
   gint clips_available;
@@ -230,20 +278,20 @@ typedef struct {
   gchar set_name[256];   // actually 128 is the limit now
 
   // playback
-  gboolean faded;
-  gboolean double_size;
-  gboolean sep_win;
-  gboolean fs;
-  gboolean loop;
-  gboolean loop_cont;
-  gboolean ping_pong;
-  gboolean mute;
-  gboolean must_resize; ///< fixed playback size in gui; playback plugins have their own fwidth and fheight
+  boolean faded;
+  boolean double_size;
+  boolean sep_win;
+  boolean fs;
+  boolean loop;
+  boolean loop_cont;
+  boolean ping_pong;
+  boolean mute;
+  boolean must_resize; ///< fixed playback size in gui; playback plugins have their own fwidth and fheight
   gint audio_start;
   gint audio_end;
 
-  gboolean ext_playback; ///< using external video playback plugin
-  volatile gboolean ext_keyboard; ///< keyboard codes must be polled from video playback plugin
+  boolean ext_playback; ///< using external video playback plugin
+  volatile boolean ext_keyboard; ///< keyboard codes must be polled from video playback plugin
 
   gint ptr_x;
   gint ptr_y;
@@ -252,28 +300,29 @@ typedef struct {
 
 
   // flags
-  gboolean save_with_sound;
-  gboolean ccpd_with_sound;
-  gboolean selwidth_locked;
-  gboolean is_ready;
-  gboolean opening_loc;  ///< opening location (streaming)
-  gboolean dvgrab_preview;
-  gboolean switch_during_pb;
-  gboolean clip_switched; ///< for recording - did we switch clips ?
-  gboolean record;
+  boolean save_with_sound;
+  boolean ccpd_with_sound;
+  boolean selwidth_locked;
+  boolean is_ready;
+  boolean fatal; ///< got fatal signal
+  boolean opening_loc;  ///< opening location (streaming)
+  boolean dvgrab_preview;
+  boolean switch_during_pb;
+  boolean clip_switched; ///< for recording - did we switch clips ?
+  boolean record;
 
-  gboolean in_fs_preview;
+  boolean in_fs_preview;
   volatile lives_cancel_t cancelled;
 
-  gboolean error;
+  boolean error;
 
   lives_cancel_type_t cancel_type;
 
   weed_plant_t *event_list; ///< current event_list, for recording
   weed_plant_t *stored_event_list; ///< stored mt -> clip editor
-  gboolean stored_event_list_changed;
-  gboolean stored_event_list_auto_changed;
-  gboolean stored_layout_save_all_vals;
+  boolean stored_event_list_changed;
+  boolean stored_event_list_auto_changed;
+  boolean stored_layout_save_all_vals;
   gchar stored_layout_name[PATH_MAX];
 
   GList *stored_layout_undos;
@@ -288,26 +337,32 @@ typedef struct {
 
   lives_whentostop_t whentostop;
 
-  gboolean noframedrop;
+  boolean noframedrop;
 
   gint play_start;
   gint play_end;
-  gboolean playing_sel;
-  gboolean preview;
+  boolean playing_sel;
+  boolean preview;
 
-  gboolean is_processing;
-  gboolean is_rendering;
-  gboolean resizing;
+  boolean is_processing;
+  boolean is_rendering;
+  boolean resizing;
 
-  gboolean foreign;  ///< for external window capture
-  gboolean record_foreign;
-  gboolean t_hidden;
+  boolean foreign;  ///< for external window capture
+  boolean record_foreign;
+  boolean t_hidden;
 
   // recording from an external window
   guint foreign_key;
+
+
+#if GTK_CHECK_VERSION(3,0,0)
+  Window foreign_id;
+#else
   GdkNativeWindow foreign_id;
   GdkColormap *foreign_cmap;
   GdkPixmap *foreign_map;
+#endif
   GdkWindow *foreign_window;
   gint foreign_width;
   gint foreign_height;
@@ -315,7 +370,7 @@ typedef struct {
   gchar *foreign_visual;
 
   /// some VJ effects
-  gboolean nervous;
+  boolean nervous;
 
   lives_rfx_t *rendered_fx;
   gint num_rendered_effects_builtin;
@@ -325,9 +380,9 @@ typedef struct {
   // for the merge dialog
   gint last_transition_idx;
   gint last_transition_loops;
-  gboolean last_transition_loop_to_fit;
-  gboolean last_transition_align_start;
-  gboolean last_transition_ins_frames;
+  boolean last_transition_loop_to_fit;
+  boolean last_transition_align_start;
+  boolean last_transition_ins_frames;
 
 
   guint64 rte; ///< current max for VJ mode == 64 effects on fg clip
@@ -350,17 +405,17 @@ typedef struct {
   gint pre_src_file; ///< video file we were playing before any ext input started
   gint pre_src_audio_file; ///< audio file we were playing before any ext input started
 
-  gint scr_width;
-  gint scr_height;
+  int scr_width;
+  int scr_height;
   lives_toy_t toy_type;
   lives_pid_t toy_alives_pid; // 0, or thread for autolives toy
-  gboolean autolives_reset_fx;
+  boolean autolives_reset_fx;
 
-  gboolean toy_go_wild;
+  boolean toy_go_wild;
 
   // copy/paste
-  gboolean insert_after;
-  gboolean with_sound;
+  boolean insert_after;
+  boolean with_sound;
 
   // selection
   gint sel_start;
@@ -377,7 +432,7 @@ typedef struct {
 #define PREFS_THEME_CHANGED (1<<0)
 #define PREFS_JACK_CHANGED (1<<1)
 #define PREFS_TEMPDIR_CHANGED (1<<2)
-  gboolean prefs_need_restart;
+  boolean prefs_need_restart;
 
   /// default sizes for when no file is loaded
   gint def_width;
@@ -391,15 +446,15 @@ typedef struct {
 
   // end of static-ish info
   gchar first_info_file[PATH_MAX];
-  gboolean leave_files;
-  gboolean was_set;
+  boolean leave_files;
+  boolean was_set;
 
   /// extra parameters for opening special files
   gchar *file_open_params;
-  gboolean open_deint;
+  boolean open_deint;
 
   gint last_dprint_file;
-  gboolean no_switch_dprint;
+  boolean no_switch_dprint;
 
   /// actual frame being displayed
   gint actual_frame;
@@ -422,21 +477,21 @@ typedef struct {
   gint64 stream_ticks;  ///< ticks since first frame sent to playback plugin
   gint64 last_display_ticks; /// currticks when last display was shown (used for fixed fps)
 
-  gboolean size_warn; ///< warn the user that incorrectly sized frames were found
+  boolean size_warn; ///< warn the user that incorrectly sized frames were found
 
   /// set to TRUE during frame load/display operation. If TRUE we should not switch clips, 
   /// close the current clip, or call load_frame_image()
-  gboolean noswitch; 
+  boolean noswitch; 
   gint new_clip;
 
   gint aud_file_to_kill; ///< # of audio file to kill on crash
 
-  gboolean reverse_pb; ///< used in osc.c
+  boolean reverse_pb; ///< used in osc.c
 
   /// TODO - make this a mutex and more finely grained : things we need to block are (clip switches, clip closure, effects on/off, etc)
-  gboolean osc_block;
+  boolean osc_block;
 
-  gboolean osc_auto; ///< bypass user choices automatically
+  boolean osc_auto; ///< bypass user choices automatically
 
   /// encode width, height and fps set externally
   gint osc_enc_width;
@@ -450,7 +505,7 @@ typedef struct {
   gdouble fixed_fpsd; ///< <=0. means free playback
 
   /// video playback plugin was updated; write settings to a file
-  gboolean write_vpp_file;
+  boolean write_vpp_file;
 
   volatile gshort scratch;
 #define SCRATCH_NONE 0
@@ -459,10 +514,10 @@ typedef struct {
 #define SCRATCH_JUMP 2
 
   /// internal fx
-  gboolean internal_messaging;
-  lives_render_error_t (*progress_fn) (gboolean reset);
+  boolean internal_messaging;
+  lives_render_error_t (*progress_fn) (boolean reset);
 
-  volatile gboolean threaded_dialog;
+  volatile boolean threaded_dialog;
 
   // fx controls
   gdouble fx1_val;
@@ -487,15 +542,15 @@ typedef struct {
   gint fx3_end;
   gint fx4_end;
 
-  gboolean fx1_bool;
-  gboolean fx2_bool;
-  gboolean fx3_bool;
-  gboolean fx4_bool;
-  gboolean fx5_bool;
-  gboolean fx6_bool;
+  boolean fx1_bool;
+  boolean fx2_bool;
+  boolean fx3_bool;
+  boolean fx4_bool;
+  boolean fx5_bool;
+  boolean fx6_bool;
 
-  gboolean effects_paused;
-  gboolean did_rfx_preview;
+  boolean effects_paused;
+  boolean did_rfx_preview;
 
   //function pointers
   guint kb_timer;
@@ -519,15 +574,15 @@ typedef struct {
   gulong sepwin_cb_func;
 
   // for jack transport
-  gboolean jack_can_stop;
-  gboolean jack_can_start;
+  boolean jack_can_stop;
+  boolean jack_can_start;
 
-  volatile gboolean video_seek_ready;
+  volatile boolean video_seek_ready;
 
   // selection pointers
   gulong mouse_fn1;
-  gboolean mouse_blocked;
-  gboolean hrule_blocked;
+  boolean mouse_blocked;
+  boolean hrule_blocked;
 
   /// stored clips
   gint clipstore[FN_KEYS-1];
@@ -541,6 +596,8 @@ typedef struct {
 
   GtkWidget *frame1;
   GtkWidget *frame2;
+  GtkWidget *freventbox0;
+  GtkWidget *freventbox1;
   GtkWidget *playframe;
   GtkWidget *pl_eventbox;
   GdkPixbuf *imframe;
@@ -647,9 +704,6 @@ typedef struct {
   GtkWidget *resample_audio;
   GtkWidget *resample_video;
   GtkWidget *preferences;
-  GtkWidget *xmms_play_audio;
-  GtkWidget *xmms_random_audio;
-  GtkWidget *xmms_stop_audio;
   GtkWidget *rename;
   GtkWidget *toys;
   GtkWidget *toy_none;
@@ -703,14 +757,13 @@ typedef struct {
   GtkWidget *laudbar;
   GtkWidget *raudbar;
 
-#define MAIN_SPIN_SPACER 52 ///< pixel spacing for start/end spins for clip and multitrack editors
   GtkWidget *spinbutton_end;
   GtkWidget *spinbutton_start;
 
   GtkWidget *arrow1;
   GtkWidget *arrow2;
 
-  GdkCursor *cursor;
+  lives_cursor_t cursor_style;
 
   weed_plant_t *filter_map; // the video filter map for rendering
   weed_plant_t *afilter_map; // the audio filter map for renering
@@ -722,8 +775,6 @@ typedef struct {
   GtkWidget *play_window;
   weed_plant_t *frame_layer;
   GtkWidget *plug;
-  gulong pw_exp_func;
-  gboolean pw_exp_is_blocked;
 
   // frame preview in the separate window
   GtkWidget *preview_box;
@@ -795,6 +846,7 @@ typedef struct {
   gint opwy;
 
   // sepwin buttons
+  GtkWidget *preview_controls;
   GtkWidget *p_playbutton;
   GtkWidget *p_playselbutton;
   GtkWidget *p_rewindbutton;
@@ -804,11 +856,14 @@ typedef struct {
 
   // timer bars
   GtkWidget *video_draw;
-  GdkPixmap *video_drawable;
   GtkWidget *laudio_draw;
-  GdkPixmap *laudio_drawable;
   GtkWidget *raudio_draw;
-  GdkPixmap *raudio_drawable;
+
+  lives_painter_surface_t *video_drawable;
+  lives_painter_surface_t *laudio_drawable;
+  lives_painter_surface_t *raudio_drawable;
+  lives_painter_surface_t *blank_laudio_drawable;
+  lives_painter_surface_t *blank_raudio_drawable;
 
   // framecounter
   GtkWidget *framebar;
@@ -847,8 +902,10 @@ typedef struct {
 
   GtkWidget *resize_menuitem;
 
-  gboolean only_close; ///< only close clips - do not exit
-  gboolean is_exiting; ///< set during shutdown (inverse of only_close then)
+  boolean only_close; ///< only close clips - do not exit
+  volatile boolean is_exiting; ///< set during shutdown (inverse of only_close then)
+
+  gulong pw_scroll_func;
 
 #ifdef ENABLE_JACK
   jack_driver_t *jackd; ///< jack audio playback device
@@ -881,11 +938,11 @@ typedef struct {
   GList *xlays;
 
   gchar *recovery_file;  ///< the filename of our recover file
-  gboolean leave_recovery;
+  boolean leave_recovery;
 
-  gboolean unordered_blocks; ///< are we recording unordered blocks ?
+  boolean unordered_blocks; ///< are we recording unordered blocks ?
 
-  gboolean no_exit; ///< if TRUE, do not exit after saving set
+  boolean no_exit; ///< if TRUE, do not exit after saving set
 
   mt_opts multi_opts; ///< some multitrack options that survive between mt calls
 
@@ -923,7 +980,7 @@ typedef struct {
   gint rec_asamps;
   gint rec_signed_endian;
 
-  gboolean suppress_dprint; ///< tidy up, e.g. by blocking "switched to file..." and "closed file..." messages
+  boolean suppress_dprint; ///< tidy up, e.g. by blocking "switched to file..." and "closed file..." messages
 
   gchar *string_constants[NUM_LIVES_STRING_CONSTANTS];
   gchar *any_string;  ///< localised text saying "Any", for encoder and output format
@@ -934,28 +991,26 @@ typedef struct {
 
   gint opening_frames; ///< count of frames so far opened, updated after preview (currently)
 
-  gboolean show_procd; ///< override showing of "processing..." dialog
+  boolean show_procd; ///< override showing of "processing..." dialog
 
-  gboolean block_param_updates; ///< block visual param changes from updating real values
-  gboolean no_interp; ///< block interpolation (for single frame previews)
+  boolean block_param_updates; ///< block visual param changes from updating real values
+  boolean no_interp; ///< block interpolation (for single frame previews)
 
   weed_timecode_t cevent_tc; ///< timecode of currently processing event
 
-  gboolean opening_multi; ///< flag to indicate multiple file selection
+  boolean opening_multi; ///< flag to indicate multiple file selection
 
-  gboolean record_paused; ///< pause during recording
+  boolean record_paused; ///< pause during recording
 
-  gboolean record_starting; ///< start recording at next frame
+  boolean record_starting; ///< start recording at next frame
 
   gint img_concat_clip;  ///< when opening multiple, image files can get concatenated here (prefs->concat_images)
 
-  GdkGC *general_gc;  ///< used for colour drawing
-
   /// rendered generators
-  gboolean gen_to_clipboard;
-  gboolean is_generating;
+  boolean gen_to_clipboard;
+  boolean is_generating;
 
-  gboolean keep_pre;
+  boolean keep_pre;
 
   GtkWidget *textwidget_focus;
 
@@ -966,7 +1021,7 @@ typedef struct {
 
 
   /// external control inputs
-  gboolean ext_cntl[MAX_EXT_CNTL];
+  boolean ext_cntl[MAX_EXT_CNTL];
 
   #ifdef ALSA_MIDI
   snd_seq_t *seq_handle;
@@ -982,24 +1037,24 @@ typedef struct {
   GtkWidget *splash_label;
   GtkWidget *splash_progress;
 
-  gboolean recoverable_layout;
+  boolean recoverable_layout;
 
-  gboolean soft_debug; ///< for testing
+  boolean soft_debug; ///< for testing
 
   /// encoder text output
   GIOChannel *iochan;
   GtkTextView *optextview;
 
-  gboolean has_custom_tools;
-  gboolean has_custom_gens;
-  gboolean has_custom_utilities;
+  boolean has_custom_tools;
+  boolean has_custom_gens;
+  boolean has_custom_utilities;
 
   /// decoders
-  gboolean decoders_loaded;
+  boolean decoders_loaded;
   GList *decoder_list;
 
-  gboolean go_away;
-  gboolean debug; ///< debug crashes and asserts
+  boolean go_away;
+  boolean debug; ///< debug crashes and asserts
 
   gchar *subt_save_file; ///< name of file to save subtitles to
 
@@ -1014,7 +1069,7 @@ typedef struct {
 
   int log_fd;
 
-  gboolean jack_trans_poll;
+  boolean jack_trans_poll;
 
 #define LIVES_MAX_ALARMS 1024
 #define LIVES_NO_ALARM_TICKS -1
@@ -1024,22 +1079,31 @@ typedef struct {
 
   // stuff specific to audio gens (will be extended to all rt audio fx)
   volatile int agen_key; ///< which fx key is generating audio [1 based] (or 0 for none)
-  volatile gboolean agen_needs_reinit;
+  volatile boolean agen_needs_reinit;
   gint64 agen_samps_count; ///< count of samples since init
 
-  gboolean aplayer_broken;
+  boolean aplayer_broken;
 
-  gboolean com_failed;
-  gboolean write_failed;
-  gboolean read_failed;
-  gboolean chdir_failed;
+  boolean com_failed;
+  boolean write_failed;
+  boolean read_failed;
+  boolean chdir_failed;
 
-  gboolean add_clear_ds_button;
-  gboolean add_clear_ds_adv;
-  gboolean tried_ds_recover;
+  boolean add_clear_ds_button;
+  boolean add_clear_ds_adv;
+  boolean tried_ds_recover;
 
-  gboolean has_session_tmpdir;
-  gboolean startup_error;
+  boolean has_session_tmpdir;
+  boolean startup_error;
+
+#if GTK_CHECK_VERSION(3,0,0)
+  boolean kb_timer_end;
+#endif
+
+  boolean draw_blocked; // block drawing of timeline bars : prevents an infinite loop
+
+  int ce_frame_height;
+  int ce_frame_width;
 
   gchar *read_failed_file;
   gchar *write_failed_file;
@@ -1054,11 +1118,19 @@ typedef struct {
   lives_pconnect_t *pconx; ///< list of out -> in param connections
   lives_cconnect_t *cconx; ///< list of out -> in alpha channel connections
 
+  int overflow_height;
+
+  int rowstride_alignment;
+  int rowstride_alignment_hint;
+
+  int sepwin_minwidth;
+  int sepwin_minheight;
+
+  guint signal_caught;
+  boolean signals_deferred;
 
 } mainwindow;
 
-GdkCursor *hidden_cursor;
-
 extern _palette *palette;
 
 typedef struct {
@@ -1070,9 +1142,9 @@ typedef struct {
   GtkWidget *param_vbox;
   GtkWidget *spinbutton_loops;
 
-  gboolean loop_to_fit;
-  gboolean align_start;
-  gboolean ins_frames;
+  boolean loop_to_fit;
+  boolean align_start;
+  boolean ins_frames;
   int *list_to_rfx_index;
   GList *trans_list;
 
