@@ -1,6 +1,6 @@
 // multitrack.h
 // LiVES
-// (c) G. Finch 2005 - 2010 <salsaman@xs4all.nl,salsaman@gmail.com>
+// (c) G. Finch 2005 - 2013 <salsaman@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -9,38 +9,41 @@
 #ifndef HAS_LIVES_MULTITRACK_H
 #define HAS_LIVES_MULTITRACK_H
 
-#define CLIP_THUMB_WIDTH 72
-#define CLIP_THUMB_HEIGHT 72
 
-#define CLIP_LABEL_LENGTH 20
+////////////////////// GUI constants ///////////////////////
 
-#define BLOCK_THUMB_WIDTH 40
+
+#define CLIP_THUMB_WIDTH ((int)(72.*widget_opts.scale))
+#define CLIP_THUMB_HEIGHT ((int)(72.*widget_opts.scale))
+
+#define CLIP_LABEL_LENGTH ((int)(20.*widget_opts.scale))
+
+#define BLOCK_THUMB_WIDTH ((int)(40.*widget_opts.scale))
+
+#define MT_PLAY_WIDTH_SMALL ((int)(320.*widget_opts.scale))
+#define MT_PLAY_HEIGHT_SMALL ((int)(216.*widget_opts.scale))
+
+#define MT_PLAY_WIDTH_EXP ((int)(432.*widget_opts.scale))
+#define MT_PLAY_HEIGHT_EXP ((int)(324.*widget_opts.scale))
+
+#define MT_CTX_WIDTH ((int)(320.*widget_opts.scale))
+#define MT_CTX_HEIGHT ((int)(220.*widget_opts.scale))
+
+#define FX_BLOCK_WIDTH ((int)(80.*widget_opts.scale))
+#define FX_BLOCK_HEIGHT ((int)(20.*widget_opts.scale))
+
+#define MT_TRACK_HEIGHT ((int)(25.*widget_opts.scale))
+
+#define TIMECODE_LENGTH 14 ///< length of timecode text entry, must be >12
+
+////////////////////////////////////////////////////////////////////////////////
 
 #define BLOCK_DRAW_SIMPLE 1
 #define BLOCK_DRAW_THUMB 2
 #define BLOCK_DRAW_TYPE BLOCK_DRAW_THUMB
 
-#define MT_PLAY_WIDTH_SMALL 320
-#define MT_PLAY_HEIGHT_SMALL 216
-
-#define MT_PLAY_WIDTH_EXP 432
-#define MT_PLAY_HEIGHT_EXP 324
-
-#define MT_CTX_WIDTH 320
-#define MT_CTX_HEIGHT 220
-
-#define FX_BLOCK_WIDTH 80
-#define FX_BLOCK_HEIGHT 20
-
-
-#define TIMECODE_LENGTH 14 ///< length of timecode text entry, must be >12
-
 #define DEF_TIME 120 ///< default seconds when there is no event_list
 
-#define MT_BORDER_WIDTH 20 ///< width border for window
-
-#define IN_OUT_SEP 10 ///< min pixel separation for in/out images in poly_box (per image) 
-
 typedef struct _mt lives_mt;
 
 typedef struct _track_rect track_rect;
@@ -153,22 +156,22 @@ typedef enum {
 
 
 struct _mt_opts {
-  gboolean set; ///< have we set opts (in mainw) ?
-  gboolean move_effects; ///< should we move effects attached to a block ?
-  gboolean fx_auto_preview;
-  gboolean snap_over; ///< snap to overlap
+  boolean set; ///< have we set opts (in mainw) ?
+  boolean move_effects; ///< should we move effects attached to a block ?
+  boolean fx_auto_preview;
+  boolean snap_over; ///< snap to overlap
   lives_mt_grav_mode_t grav_mode;
   lives_mt_mouse_mode_t mouse_mode;
   lives_mt_insert_mode_t insert_mode;
-  gboolean show_audio;
-  gboolean show_ctx;
-  gboolean ign_ins_sel;
-  gboolean follow_playback;
-  gboolean insert_audio;  ///< do we insert audio with video ?
-  gboolean pertrack_audio; ///< do we want pertrack audio ?
-  gboolean audio_bleedthru; ///< should we allow all audio to bleed thru ?
-  gboolean gang_audio; ///< gang layer audio volume levels
-  gint back_audio_tracks; ///< number of backing audio tracks (currently 0 or 1)
+  boolean show_audio;
+  boolean show_ctx;
+  boolean ign_ins_sel;
+  boolean follow_playback;
+  boolean insert_audio;  ///< do we insert audio with video ?
+  boolean pertrack_audio; ///< do we want pertrack audio ?
+  boolean audio_bleedthru; ///< should we allow all audio to bleed thru ?
+  boolean gang_audio; ///< gang layer audio volume levels
+  int back_audio_tracks; ///< number of backing audio tracks (currently 0 or 1)
 };
 
 
@@ -242,6 +245,7 @@ struct _mt {
   GtkWidget *grav_left;
   GtkWidget *grav_right;
   GtkWidget *select_track;
+  GtkWidget *seldesel_menuitem;
   GtkWidget *view_events;
   GtkWidget *view_clips;
   GtkWidget *view_in_out;
@@ -322,8 +326,6 @@ struct _mt {
   GtkWidget *amixer_button;
   GtkWidget *view_sel_events;
   GtkWidget *adjust_start_end;
-  GtkWidget *in_eventbox;
-  GtkWidget *out_eventbox;
   GtkWidget *start_in_label;
   GtkWidget *end_out_label;
   GtkWidget *context_frame;
@@ -350,15 +352,12 @@ struct _mt {
   GtkWidget *gens_submenu;
   GtkWidget *capture;
 
-  GtkWidget *insa_eventbox;
   GtkWidget *insa_checkbutton;
   GtkWidget *snapo_checkbutton;
 
   GObject *spinbutton_in_adj;
   GObject *spinbutton_out_adj;
 
-  GdkCursor *cursor;
-
   GObject *hadjustment;
   GObject *node_adj;
 
@@ -375,7 +374,7 @@ struct _mt {
 
   GList *aparam_view_list;
 
-  GdkPixbuf *sepwin_pixbuf;
+  GdkPixbuf *frame_pixbuf;
 
   gulong spin_in_func;
   gulong spin_out_func;
@@ -401,105 +400,103 @@ struct _mt {
 
   gulong tc_func;
 
-  gulong node_adj_func;
-
   weed_plant_t *event_list;
 
   weed_plant_t *init_event;   ///< current editable values
   weed_plant_t *selected_init_event;  ///< currently selected in list
   ///////////////////////
-  gint num_video_tracks;
-  gdouble end_secs;  ///< max display time of timeline in seconds
+  int num_video_tracks;
+  double end_secs;  ///< max display time of timeline in seconds
 
   // timeline min and max display values
-  gdouble tl_min;
-  gdouble tl_max;
+  double tl_min;
+  double tl_max;
 
-  gint clip_selected; ///< clip in clip window
-  gint file_selected; ///< actual LiVES file struct number which clip_selected matches
-  gint current_track; ///< starts at 0
+  int clip_selected; ///< clip in clip window
+  int file_selected; ///< actual LiVES file struct number which clip_selected matches
+  int current_track; ///< starts at 0
 
   GList *selected_tracks;
 
   lives_mt_poly_state_t poly_state;  ///< state of polymorph window
 
-  gint render_file;
+  int render_file;
 
   lives_direction_t last_direction; ///< last direction timeline cursor was moved in
 
   track_rect *block_selected; ///< pointer to current selected block, or NULL
   track_rect *putative_block; ///< putative block to move or copy, or NULL
 
-  gdouble ptr_time; ///< stored timeline cursor position before playback
+  double ptr_time; ///< stored timeline cursor position before playback
 
-  gdouble tl_fixed_length; ///< length of timeline can be fixed (secs) : TODO
+  double tl_fixed_length; ///< length of timeline can be fixed (secs) : TODO
 
-  gdouble fps; ///< fps of this timeline
+  double fps; ///< fps of this timeline
 
-  gdouble region_start; ///< start of time region in seconds (or 0.)
-  gdouble region_end; ///< end of time region in seconds (or 0.)
-  gdouble region_init; ///< point where user pressed the mouse
-  gboolean region_updating;
+  double region_start; ///< start of time region in seconds (or 0.)
+  double region_end; ///< end of time region in seconds (or 0.)
+  double region_init; ///< point where user pressed the mouse
+  boolean region_updating;
 
-  gboolean is_rendering; ///< TRUE if we are in the process of rendering/pre-rendering to a clip, cf. mainw->is_rendering
-  gboolean pr_audio; ///< TRUE if we are in the process of prerendering audio to a clip
+  boolean is_rendering; ///< TRUE if we are in the process of rendering/pre-rendering to a clip, cf. mainw->is_rendering
+  boolean pr_audio; ///< TRUE if we are in the process of prerendering audio to a clip
 
-  gint max_disp_vtracks;
-  gint current_fx;
+  int max_disp_vtracks;
+  int current_fx;
 
-  gboolean mt_frame_preview;
+  boolean mt_frame_preview;
 
   lives_rfx_t *current_rfx;
 
   gchar layout_name[PATH_MAX];
 
   // cursor warping for mouse move mode
-  gdouble hotspot_x;
-  gint hotspot_y;
+  double hotspot_x;
+  int hotspot_y;
 
-  gboolean moving_block; ///< moving block flag
+  boolean moving_block; ///< moving block flag
 
   //////////////////////////////
 
-  gint sel_x;
-  gint sel_y;
+  int sel_x;
+  int sel_y;
 
   gulong mouse_mot1;
   gulong mouse_mot2;
 
-  gboolean tl_selecting; ///< for mouse select mode
+  boolean tl_selecting; ///< for mouse select mode
 
   /* start and end offset overrides for inserting (used during block move) */
   weed_timecode_t insert_start;
   weed_timecode_t insert_end;
 
   /// override for avel used during audio insert
-  gdouble insert_avel;
+  double insert_avel;
 
   GList *undos;
   size_t undo_buffer_used;
   unsigned char *undo_mem;
-  gint undo_offset;
-  gboolean did_backup;
+  int undo_offset;
+  boolean did_backup;
 
   gchar undo_text[32];
   gchar redo_text[32];
 
-  gboolean undoable;
-  gboolean redoable;
+  boolean undoable;
+  boolean redoable;
 
-  gboolean changed; ///< changed since last saved
-  gboolean auto_changed; ///< changed since last auto-saved
+  boolean changed; ///< changed since last saved
+  boolean auto_changed; ///< changed since last auto-saved
 
   int64_t auto_back_time;
 
   // stuff to do with framedraw "special" widgets
-  gint inwidth;
-  gint inheight;
-  gint outwidth;
-  gint outheight;
+  int inwidth;
+  int inheight;
+  int outwidth;
+  int outheight;
   lives_special_framedraw_rect_t *framedraw;
-  gint track_index;
+  int track_index;
 
   lives_mt_last_fx_type_t last_fx_type;
 
@@ -507,7 +504,7 @@ struct _mt {
 
   mt_opts opts;
 
-  gboolean auto_reloading;
+  boolean auto_reloading;
 
   weed_plant_t *fm_edit_event;
   weed_plant_t *moving_fx;
@@ -518,23 +515,23 @@ struct _mt {
   gulong spin_start_func;
   gulong spin_end_func;
 
-  gboolean layout_prompt; ///< on occasion, prompt user if they want to correct layout on disk or not
-  gboolean layout_set_properties;
-  gboolean ignore_load_vals;
+  boolean layout_prompt; ///< on occasion, prompt user if they want to correct layout on disk or not
+  boolean layout_set_properties;
+  boolean ignore_load_vals;
 
-  gdouble user_fps;
-  gint user_width;
-  gint user_height;
-  gint user_arate;
-  gint user_achans;
-  gint user_asamps;
-  gint user_signed_endian;
+  double user_fps;
+  int user_width;
+  int user_height;
+  int user_arate;
+  int user_achans;
+  int user_asamps;
+  int user_signed_endian;
 
-  gboolean render_vidp;
-  gboolean render_audp;
-  gboolean normalise_audp;
+  boolean render_vidp;
+  boolean render_audp;
+  boolean normalise_audp;
 
-  gint exact_preview;
+  int exact_preview;
 
 
   GList *tl_marks;
@@ -544,40 +541,40 @@ struct _mt {
 
   weed_plant_t *specific_event; ///< a pointer to some generally interesting event
 
-  gdouble context_time; ///< this is set when the user right clicks on a track, otherwise -1.
-  gboolean use_context;
+  double context_time; ///< this is set when the user right clicks on a track, otherwise -1.
+  boolean use_context;
 
-  gint cursor_style;
+  lives_cursor_t cursor_style;
 
-  gboolean is_paused;
+  boolean is_paused;
 
   /* current size of frame inside playback/preview area */
-  gint play_width;
-  gint play_height;
+  int play_width;
+  int play_height;
 
   /* current size of playback/preview area */
-  gint play_window_width;
-  gint play_window_height;
+  int play_window_width;
+  int play_window_height;
 
-  gint selected_filter; ///< filter selected in poly window tab
+  int selected_filter; ///< filter selected in poly window tab
 
-  gint top_track; ///< top (video) track in scrolled window
+  int top_track; ///< top (video) track in scrolled window
 
-  gboolean redraw_block; ///< block drawing of playback cursor during track redraws
+  boolean redraw_block; ///< block drawing of playback cursor during track redraws
 
-  gboolean was_undo_redo;
+  boolean was_undo_redo;
 
-  gboolean no_expose; ///< block timeline expose while we are exiting
+  boolean no_expose; ///< block timeline expose while we are exiting
 
-  gboolean is_ready;
+  boolean is_ready;
 
-  gboolean aud_track_selected;
+  boolean aud_track_selected;
 
-  gboolean has_audio_file;
+  boolean has_audio_file;
 
-  gboolean tl_mouse;
+  boolean tl_mouse;
 
-  gboolean playing_sel; ///< are we playing just the time selection ?
+  boolean playing_sel; ///< are we playing just the time selection ?
 
   guint idlefunc; ///< autobackup function 
 
@@ -585,12 +582,12 @@ struct _mt {
 
   lives_amixer_t *amixer;
 
-  gdouble prev_fx_time;
+  double prev_fx_time;
 
-  gboolean block_tl_move; ///< set to TRUE to block moving timeline (prevents loops with the node spinbutton)
-  gboolean block_node_spin; ///< set to TRUE to block moving node spinner (prevents loops with the timeline)
+  boolean block_tl_move; ///< set to TRUE to block moving timeline (prevents loops with the node spinbutton)
+  boolean block_node_spin; ///< set to TRUE to block moving node spinner (prevents loops with the timeline)
 
-  gboolean is_atrans; /// < force some visual changes when applying autotrans
+  boolean is_atrans; /// < force some visual changes when applying autotrans
 
 };  // lives_mt
 
@@ -611,7 +608,7 @@ struct _lives_amixer_t {
   GtkWidget *gang_checkbutton;
   GtkWidget *inv_checkbutton;
   gulong *ch_slider_fns;
-  gint nchans;
+  int nchans;
   lives_mt *mt;
 };
 
@@ -633,9 +630,9 @@ struct _track_rect {
   weed_timecode_t offset_start; ///< offset in sourcefile of first frame
 
   lives_mt_block_state_t state;
-  gboolean start_anchored;
-  gboolean end_anchored;
-  gboolean ordered; ///< are frames in sequential order ?
+  boolean start_anchored;
+  boolean end_anchored;
+  boolean ordered; ///< are frames in sequential order ?
   
   GtkWidget *eventbox; ///< pointer to eventbox widget which contains this block; we can use its "layer_number" to get the track/layer number
 
@@ -652,7 +649,7 @@ typedef struct {
 /* clip->layout use mapping, from layout.map file */
 typedef struct {
   gchar *handle;
-  gint64 unique_id;
+  int64_t unique_id;
   gchar *name;
   GList *list;
 } layout_map;
@@ -665,12 +662,12 @@ typedef struct {
 
 // setup functions
 
-lives_mt *multitrack (weed_plant_t *, gint orig_file, gdouble fps); ///< create and return lives_mt struct
-void mt_init_tracks (lives_mt *, gboolean set_min_max);  ///< add basic tracks, or set tracks from mt->event_list
-gboolean on_multitrack_activate (GtkMenuItem *menuitem, weed_plant_t *event_list); ///< menuitem callback
+lives_mt *multitrack (weed_plant_t *, int orig_file, double fps); ///< create and return lives_mt struct
+void mt_init_tracks (lives_mt *, boolean set_min_max);  ///< add basic tracks, or set tracks from mt->event_list
+boolean on_multitrack_activate (GtkMenuItem *menuitem, weed_plant_t *event_list); ///< menuitem callback
 
 // delete function
-gboolean multitrack_delete (lives_mt *, gboolean save);
+boolean multitrack_delete (lives_mt *, boolean save);
 
 // morph the poly window
 void polymorph (lives_mt *, lives_mt_poly_state_t poly);
@@ -741,47 +738,47 @@ void mt_ign_ins_sel_toggled (GtkMenuItem *, gpointer mt);
 void mt_change_max_disp_tracks (GtkMenuItem *, gpointer mt);
 
 // event_list functions
-weed_plant_t *add_blank_frames_up_to (weed_plant_t *event_list, weed_plant_t *start_event, weed_timecode_t end_tc, gdouble fps);
+weed_plant_t *add_blank_frames_up_to (weed_plant_t *event_list, weed_plant_t *start_event, weed_timecode_t end_tc, double fps);
 
 // track functions
 void on_cback_audio_activate (GtkMenuItem *, gpointer mt);
-GtkWidget *add_audio_track (lives_mt *, gint trackno, gboolean behind);
+GtkWidget *add_audio_track (lives_mt *, int trackno, boolean behind);
 void add_video_track_behind (GtkMenuItem *, gpointer mt);
 void add_video_track_front (GtkMenuItem *, gpointer mt);
-void delete_video_track(lives_mt *, gint layer, gboolean full);
-void delete_audio_track(lives_mt *, GtkWidget *eventbox, gboolean full);
-void delete_audio_tracks(lives_mt *, GList *list, gboolean full);
+void delete_video_track(lives_mt *, int layer, boolean full);
+void delete_audio_track(lives_mt *, GtkWidget *eventbox, boolean full);
+void delete_audio_tracks(lives_mt *, GList *list, boolean full);
 void remove_gaps (GtkMenuItem *, gpointer mt);
 void remove_first_gaps (GtkMenuItem *, gpointer mt);
 void on_insgap_sel_activate (GtkMenuItem *, gpointer mt);
 void on_insgap_cur_activate (GtkMenuItem *, gpointer mt);
 void on_split_activate (GtkMenuItem *, gpointer mt);
-void scroll_tracks (lives_mt *, gint top_track);
-gboolean track_arrow_pressed (GtkWidget *ahbox, GdkEventButton *, gpointer mt);
+void scroll_tracks (lives_mt *, int top_track, boolean set_value);
+boolean track_arrow_pressed (GtkWidget *ahbox, GdkEventButton *, gpointer mt);
 void track_select (lives_mt *); ///< must call after setting mt->current_track
-gboolean mt_track_is_audio(lives_mt *, int ntrack); ///< return TRUE if ntrack is a valid backing audio track
-gboolean mt_track_is_video(lives_mt *, int ntrack); ///< return TRUE if ntrack is a valid video track
+boolean mt_track_is_audio(lives_mt *, int ntrack); ///< return TRUE if ntrack is a valid backing audio track
+boolean mt_track_is_video(lives_mt *, int ntrack); ///< return TRUE if ntrack is a valid video track
 
 void mt_do_autotransition(lives_mt *, track_rect *block); ///< call this on a block to apply autotransition on it
 
 
 // track mouse movement
-gboolean on_track_click (GtkWidget *eventbox, GdkEventButton *, gpointer mt);
-gboolean on_atrack_click (GtkWidget *eventbox, GdkEventButton *, gpointer mt);
-gboolean on_track_header_click (GtkWidget *eventbox, GdkEventButton *, gpointer mt);
-gboolean on_track_between_click (GtkWidget *eventbox, GdkEventButton *, gpointer mt);
-gboolean on_track_release (GtkWidget *eventbox, GdkEventButton *event, gpointer mt);
-gboolean on_atrack_release (GtkWidget *eventbox, GdkEventButton *event, gpointer mt);
-gboolean on_track_header_release (GtkWidget *eventbox, GdkEventButton *, gpointer mt);
-gboolean on_track_between_release (GtkWidget *eventbox, GdkEventButton *, gpointer mt);
-gboolean on_track_move (GtkWidget *widget, GdkEventMotion *event, gpointer mt);
-gboolean on_track_header_move (GtkWidget *widget, GdkEventMotion *event, gpointer mt);
+boolean on_track_click (GtkWidget *eventbox, GdkEventButton *, gpointer mt);
+boolean on_atrack_click (GtkWidget *eventbox, GdkEventButton *, gpointer mt);
+boolean on_track_header_click (GtkWidget *eventbox, GdkEventButton *, gpointer mt);
+boolean on_track_between_click (GtkWidget *eventbox, GdkEventButton *, gpointer mt);
+boolean on_track_release (GtkWidget *eventbox, GdkEventButton *event, gpointer mt);
+boolean on_atrack_release (GtkWidget *eventbox, GdkEventButton *event, gpointer mt);
+boolean on_track_header_release (GtkWidget *eventbox, GdkEventButton *, gpointer mt);
+boolean on_track_between_release (GtkWidget *eventbox, GdkEventButton *, gpointer mt);
+boolean on_track_move (GtkWidget *widget, GdkEventMotion *event, gpointer mt);
+boolean on_track_header_move (GtkWidget *widget, GdkEventMotion *event, gpointer mt);
 
 void unselect_all (lives_mt *); ///< unselect all blocks
-void insert_frames (gint filenum, weed_timecode_t offset_start, weed_timecode_t offset_end, weed_timecode_t tc, lives_direction_t direction, GtkWidget *eventbox, lives_mt *, track_rect *in_block);
-void insert_audio (gint filenum, weed_timecode_t offset_start, weed_timecode_t offset_end, weed_timecode_t tc, gdouble avel, lives_direction_t direction, GtkWidget *eventbox, lives_mt *, track_rect *in_block);
+void insert_frames (int filenum, weed_timecode_t offset_start, weed_timecode_t offset_end, weed_timecode_t tc, lives_direction_t direction, GtkWidget *eventbox, lives_mt *, track_rect *in_block);
+void insert_audio (int filenum, weed_timecode_t offset_start, weed_timecode_t offset_end, weed_timecode_t tc, double avel, lives_direction_t direction, GtkWidget *eventbox, lives_mt *, track_rect *in_block);
 void on_seltrack_toggled (GtkWidget *, gpointer mt);
-void scroll_track_by_scrollbar (GtkVScrollbar *sbar, gpointer mt);
+void scroll_track_by_scrollbar (GtkScrollbar *sbar, gpointer mt);
 
 // block functions
 void in_out_start_changed (GtkWidget *, gpointer mt);
@@ -792,29 +789,26 @@ void avel_reverse_toggled (GtkToggleButton *, gpointer mt);
 void avel_spin_changed (GtkSpinButton *, gpointer mt);
 
 // block API functions
-gint mt_get_last_block_number(lives_mt *, int ntrack); ///< get index of last inserted (wallclock time) block for track
-gint mt_get_block_count(lives_mt *, int ntrack); ///< count blocks in track
-gdouble mt_get_block_sttime(lives_mt *, int ntrack, int iblock); /// get timeline start time of block
-gdouble mt_get_block_entime(lives_mt *, int ntrack, int iblock); /// get timeline end time of block
+int mt_get_last_block_number(lives_mt *, int ntrack); ///< get index of last inserted (wallclock time) block for track
+int mt_get_block_count(lives_mt *, int ntrack); ///< count blocks in track
+double mt_get_block_sttime(lives_mt *, int ntrack, int iblock); /// get timeline start time of block
+double mt_get_block_entime(lives_mt *, int ntrack, int iblock); /// get timeline end time of block
 
 
 // timeline functions
-void mt_tl_move(lives_mt *, gdouble pos_rel);
-void set_timeline_end_secs (lives_mt *, gdouble secs);
-gboolean on_timeline_press (GtkWidget *, GdkEventButton *, gpointer mt);
-gboolean on_timeline_release (GtkWidget *, GdkEventButton *, gpointer mt);
-gboolean on_timeline_update (GtkWidget *, GdkEventMotion *, gpointer mt);
-gint expose_timeline_reg_event (GtkWidget *, GdkEventExpose *, gpointer mt);
-gint mt_expose_laudtrack_event (GtkWidget *ebox, GdkEventExpose *, gpointer mt);
-gint mt_expose_raudtrack_event (GtkWidget *ebox, GdkEventExpose *, gpointer mt);
+void mt_tl_move(lives_mt *, double pos_rel);
+void set_timeline_end_secs (lives_mt *, double secs);
+boolean on_timeline_press (GtkWidget *, GdkEventButton *, gpointer mt);
+boolean on_timeline_release (GtkWidget *, GdkEventButton *, gpointer mt);
+boolean on_timeline_update (GtkWidget *, GdkEventMotion *, gpointer mt);
 void draw_region (lives_mt *mt);
 void tc_to_rs (GtkMenuItem *, gpointer mt);
 void tc_to_re (GtkMenuItem *, gpointer mt);
 void rs_to_tc (GtkMenuItem *, gpointer mt);
 void re_to_tc (GtkMenuItem *, gpointer mt);
-gboolean mt_mark_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data);
+boolean mt_mark_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data);
 void multitrack_clear_marks (GtkMenuItem *, gpointer mt);
-void mt_show_current_frame(lives_mt *, gboolean return_layer);  ///< preview the current frame
+void mt_show_current_frame(lives_mt *, boolean return_layer);  ///< preview the current frame
 void mt_clear_timeline(lives_mt *mt);
 
 
@@ -823,7 +817,7 @@ void clear_context (lives_mt *);
 void add_context_label (lives_mt *, const gchar *text);
 void mouse_mode_context(lives_mt *);
 void do_sel_context (lives_mt *);
-void do_fx_list_context (lives_mt *, gint fxcount);
+void do_fx_list_context (lives_mt *, int fxcount);
 void do_fx_move_context(lives_mt *mt);
 
 // playback / animation
@@ -842,32 +836,34 @@ void on_next_node_clicked  (GtkWidget *, gpointer mt);
 void on_prev_node_clicked  (GtkWidget *, gpointer mt);
 void on_del_node_clicked  (GtkWidget *, gpointer mt);
 void on_node_spin_value_changed (GtkSpinButton *, gpointer mt);
-gdouble mt_get_effect_time(lives_mt *);
+double mt_get_effect_time(lives_mt *);
 
 void on_frame_preview_clicked (GtkButton *, gpointer mt);
 void show_preview (lives_mt *, weed_timecode_t tc);
 
-// filter list controls
-weed_plant_t *get_prev_fm (lives_mt *, gint current_track, weed_plant_t *frame);
-weed_plant_t *get_next_fm (lives_mt *, gint current_track, weed_plant_t *frame);
+boolean add_mt_param_box(lives_mt *);
 
-void on_prev_fm_clicked  (GtkWidget *button, gpointer user_data);
-void on_next_fm_clicked  (GtkWidget *button, gpointer user_data);
-void on_fx_insb_clicked  (GtkWidget *button, gpointer user_data);
-void on_fx_insa_clicked  (GtkWidget *button, gpointer user_data);
+// filter list controls
+weed_plant_t *get_prev_fm (lives_mt *, int current_track, weed_plant_t *frame);
+weed_plant_t *get_next_fm (lives_mt *, int current_track, weed_plant_t *frame);
+
+void on_prev_fm_clicked  (GtkWidget *button, gpointer mt);
+void on_next_fm_clicked  (GtkWidget *button, gpointer mt);
+void on_fx_insb_clicked  (GtkWidget *button, gpointer mt);
+void on_fx_insa_clicked  (GtkWidget *button, gpointer mt);
 
 // utils
-guint event_list_get_byte_size(lives_mt *mt, weed_plant_t *event_list, int *num_events);  ///< returns bytes and sets num_events
-gboolean event_list_rectify(lives_mt *, weed_plant_t *event_listy);
-gboolean make_backup_space (lives_mt *, size_t space_needed);
+guint event_list_get_byte_size(lives_mt *, weed_plant_t *event_list, int *num_events);  ///< returns bytes and sets num_events
+boolean event_list_rectify(lives_mt *, weed_plant_t *event_listy);
+boolean make_backup_space (lives_mt *, size_t space_needed);
 void activate_mt_preview(lives_mt *); ///< sensitize Show Preview and Apply buttons
 void **mt_get_pchain(void);
 void event_list_free_undos(lives_mt *);
-gboolean used_in_current_layout(lives_mt *, gint file);
+boolean used_in_current_layout(lives_mt *, int file);
 
 // event_list utilities
-gboolean compare_filter_maps(weed_plant_t *fm1, weed_plant_t *fm2, gint ctrack); ///< ctrack can be -1 to compare all events, else we cf for ctrack
-void move_init_in_filter_map(lives_mt *mt, weed_plant_t *event_list, weed_plant_t *fmap, weed_plant_t *ifrom, weed_plant_t *ito, gint track, gboolean after);
+boolean compare_filter_maps(weed_plant_t *fm1, weed_plant_t *fm2, int ctrack); ///< ctrack can be -1 to compare all events, else we cf for ctrack
+void move_init_in_filter_map(lives_mt *, weed_plant_t *event_list, weed_plant_t *fmap, weed_plant_t *ifrom, weed_plant_t *ito, int track, boolean after);
 void update_filter_events(lives_mt *, weed_plant_t *first_event, weed_timecode_t start_tc, weed_timecode_t end_tc, int track, weed_timecode_t new_start_tc, int new_track);
 void mt_fixup_events(lives_mt *, weed_plant_t *old_event, weed_plant_t *new_event);
 
@@ -885,12 +881,12 @@ void wipe_layout(lives_mt *);
 
 void migrate_layouts (const gchar *old_set_name, const gchar *new_set_name);
 
-GList *layout_frame_is_affected(gint clipno, gint frame);
-GList *layout_audio_is_affected(gint clipno, gdouble time);
+GList *layout_frame_is_affected(int clipno, int frame);
+GList *layout_audio_is_affected(int clipno, double time);
 
-gboolean check_for_layout_del (lives_mt *, gboolean exiting);
+boolean check_for_layout_del (lives_mt *, boolean exiting);
 
-void stored_event_list_free_all(gboolean wiped);
+void stored_event_list_free_all(boolean wiped);
 void stored_event_list_free_undos(void);
 void remove_current_from_affected_layouts(lives_mt *);
 
@@ -899,33 +895,29 @@ void remove_current_from_affected_layouts(lives_mt *);
 guint mt_idle_add(lives_mt *);
 void recover_layout(GtkButton *, gpointer);
 void recover_layout_cancelled(GtkButton *, gpointer user_data);
-gboolean write_backup_layout_numbering(lives_mt *);
-
-
-// internal functions
-void mouse_select_end(GtkWidget *, lives_mt *);
+boolean write_backup_layout_numbering(lives_mt *);
 
 
 // amixer funcs
 void amixer_show (GtkButton *, gpointer mt);
 void on_amixer_close_clicked (GtkButton *, lives_mt *mt);
-GtkWidget * amixer_add_channel_slider (lives_mt *, gint i);
+GtkWidget * amixer_add_channel_slider (lives_mt *, int i);
 
 
 // misc
-void mt_change_disp_tracks_ok (GtkButton *, gpointer user_data);
-void mt_swap_play_pause (lives_mt *, gboolean put_pause);
-gchar *set_values_from_defs(lives_mt *, gboolean from_prefs);
+void mt_change_disp_tracks_ok (GtkButton *, gpointer mt);
+void mt_swap_play_pause (lives_mt *, boolean put_pause);
+gchar *set_values_from_defs(lives_mt *, boolean from_prefs);
 
 
 // clip boxes
-void mt_clip_select (lives_mt *, gboolean scroll);
-void mt_delete_clips(lives_mt *, gint file);
-void mt_init_clips (lives_mt *, gint orig_file, gboolean add);
+void mt_clip_select (lives_mt *, boolean scroll);
+void mt_delete_clips(lives_mt *, int file);
+void mt_init_clips (lives_mt *, int orig_file, boolean add);
 
 // key shortcuts
-gboolean mt_prevclip (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data);
-gboolean mt_nextclip (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data);
+boolean mt_prevclip (GtkAccelGroup *, GObject *, guint keyval, GdkModifierType mod, gpointer);
+boolean mt_nextclip (GtkAccelGroup *, GObject *, guint keyval, GdkModifierType mod, gpointer);
 
 typedef enum {
   /* default to warn about */
