@@ -164,9 +164,9 @@ void fd_tweak(lives_rfx_t *rfx) {
   if (rfx->props&RFX_PROPS_MAY_RESIZE) {
     if (framedraw.type!=LIVES_PARAM_SPECIAL_TYPE_NONE) {
       // for effects which can resize, and have a special framedraw, we will use original sized image
-      gtk_widget_hide(mainw->framedraw_preview);
-      gtk_widget_set_sensitive(mainw->framedraw_spinbutton,TRUE);
-      gtk_widget_set_sensitive(mainw->framedraw_scale,TRUE);
+      lives_widget_hide(mainw->framedraw_preview);
+      lives_widget_set_sensitive(mainw->framedraw_spinbutton,TRUE);
+      lives_widget_set_sensitive(mainw->framedraw_scale,TRUE);
     }
   }
 }
@@ -199,14 +199,14 @@ void check_for_special (lives_rfx_t *rfx, lives_param_t *param, LiVESBox *pbox)
     param->special_type=framedraw.type;
     param->special_type_index=0;
     if (framedraw.type==LIVES_PARAM_SPECIAL_TYPE_RECT_DEMASK)
-      gtk_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),0.);
+      lives_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),0.);
     g_signal_connect_after (GTK_OBJECT (param->widgets[0]), "value_changed", G_CALLBACK (after_framedraw_widget_changed), &framedraw);
   }
   if (param==framedraw.ystart_param) {
     param->special_type=framedraw.type;
     param->special_type_index=1;
     if (framedraw.type==LIVES_PARAM_SPECIAL_TYPE_RECT_DEMASK)
-      gtk_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),0.);
+      lives_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),0.);
     g_signal_connect_after (GTK_OBJECT (param->widgets[0]), "value_changed", G_CALLBACK (after_framedraw_widget_changed), &framedraw);
   }
   if (mainw->current_file>-1) {
@@ -214,14 +214,14 @@ void check_for_special (lives_rfx_t *rfx, lives_param_t *param, LiVESBox *pbox)
       param->special_type=framedraw.type;
       param->special_type_index=2;
       if (framedraw.type==LIVES_PARAM_SPECIAL_TYPE_RECT_DEMASK)
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)cfile->hsize);
+	lives_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)cfile->hsize);
       g_signal_connect_after (GTK_OBJECT (param->widgets[0]), "value_changed", G_CALLBACK (after_framedraw_widget_changed), &framedraw);
     }
     if (param==framedraw.yend_param) {
       param->special_type=framedraw.type;
       param->special_type_index=3;
       if (framedraw.type==LIVES_PARAM_SPECIAL_TYPE_RECT_DEMASK)
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)cfile->vsize);
+	lives_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)cfile->vsize);
       g_signal_connect_after (GTK_OBJECT (param->widgets[0]), "value_changed", G_CALLBACK (after_framedraw_widget_changed), &framedraw);
     }
 
@@ -244,19 +244,19 @@ void check_for_special (lives_rfx_t *rfx, lives_param_t *param, LiVESBox *pbox)
     }
     
     if (param==aspect.width_param) {
-      gtk_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)cfile->hsize);
+      lives_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)cfile->hsize);
       aspect.width_func=g_signal_connect_after (GTK_OBJECT (param->widgets[0]), "value_changed",
 						G_CALLBACK (after_aspect_width_changed),
 						NULL);
     }
     if (param==aspect.height_param) {
-      gtk_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)cfile->vsize);
+      lives_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)cfile->vsize);
       aspect.height_func=g_signal_connect_after (GTK_OBJECT (param->widgets[0]), "value_changed",
 						 G_CALLBACK (after_aspect_height_changed),
 						 NULL);
       
       box = lives_hbox_new (FALSE, 0);
-      gtk_box_pack_start (GTK_BOX (GTK_WIDGET (pbox)), box, FALSE, FALSE, widget_opts.packing_height*2);
+      lives_box_pack_start (GTK_BOX (GTK_WIDGET (pbox)), box, FALSE, FALSE, widget_opts.packing_height*2);
       
       
       add_fill_to_box(GTK_BOX(box));
@@ -268,7 +268,7 @@ void check_for_special (lives_rfx_t *rfx, lives_param_t *param, LiVESBox *pbox)
 
       add_fill_to_box(GTK_BOX(box));
 
-      gtk_widget_show_all(box);
+      lives_widget_show_all(box);
 
       aspect.checkbutton=checkbutton;
     }
@@ -297,11 +297,11 @@ void check_for_special (lives_rfx_t *rfx, lives_param_t *param, LiVESBox *pbox)
       g_list_free(clist);
 
       buttond = lives_standard_file_button_new (FALSE,g_get_current_dir());
-      gtk_box_pack_start(GTK_BOX(box),buttond,FALSE,FALSE,widget_opts.packing_width);
+      lives_box_pack_start(GTK_BOX(box),buttond,FALSE,FALSE,widget_opts.packing_width);
       gtk_box_reorder_child(GTK_BOX(box),buttond,epos); // insert after label, before textbox
       g_signal_connect(buttond, "clicked", G_CALLBACK (on_filesel_button_clicked), (gpointer)param->widgets[0]);
 
-      if (!lives_widget_is_sensitive(param->widgets[0])) gtk_widget_set_sensitive(buttond,FALSE);
+      if (!lives_widget_is_sensitive(param->widgets[0])) lives_widget_set_sensitive(buttond,FALSE);
 
       if (GTK_IS_ENTRY(param->widgets[0])) {
 	lives_entry_set_editable(LIVES_ENTRY(param->widgets[0]),FALSE);
@@ -334,14 +334,14 @@ void check_for_special (lives_rfx_t *rfx, lives_param_t *param, LiVESBox *pbox)
       }
 
       hbox = lives_hbox_new (FALSE, 0);
-      gtk_box_pack_start (GTK_BOX (GTK_WIDGET (box)), hbox, FALSE, FALSE, widget_opts.packing_height);
+      lives_box_pack_start (GTK_BOX (GTK_WIDGET (box)), hbox, FALSE, FALSE, widget_opts.packing_height);
       
       checkbutton = lives_standard_check_button_new (_("Display Password"),FALSE,LIVES_BOX(hbox),NULL);
 
       gtk_button_set_focus_on_click (GTK_BUTTON(checkbutton),FALSE);
 
-      if (!lives_widget_is_sensitive(param->widgets[0])) gtk_widget_set_sensitive(checkbutton,FALSE);
-      gtk_widget_show_all(hbox);
+      if (!lives_widget_is_sensitive(param->widgets[0])) lives_widget_set_sensitive(checkbutton,FALSE);
+      lives_widget_show_all(hbox);
 
       g_signal_connect_after (GTK_OBJECT (checkbutton), "toggled",
 			      G_CALLBACK (passwd_toggle_vis),
@@ -361,8 +361,8 @@ void check_for_special (lives_rfx_t *rfx, lives_param_t *param, LiVESBox *pbox)
 void after_aspect_width_changed (GtkSpinButton *spinbutton, gpointer user_data) {
   if (lives_toggle_button_get_active (LIVES_TOGGLE_BUTTON (aspect.checkbutton))) {
     boolean keepeven=FALSE;
-    gint width=gtk_spin_button_get_value_as_int (spinbutton);
-    gint height=gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (aspect.height_param->widgets[0]));
+    gint width=lives_spin_button_get_value_as_int (spinbutton);
+    gint height=lives_spin_button_get_value_as_int (GTK_SPIN_BUTTON (aspect.height_param->widgets[0]));
     g_signal_handler_block (aspect.height_param->widgets[0],aspect.height_func);
 
     if (((cfile->hsize>>1)<<1)==cfile->hsize&&((cfile->vsize>>1)<<1)==cfile->vsize) {
@@ -381,7 +381,7 @@ void after_aspect_width_changed (GtkSpinButton *spinbutton, gpointer user_data)
       }
     }
 
-    gtk_spin_button_set_value (GTK_SPIN_BUTTON (aspect.height_param->widgets[0]), (gdouble)height);
+    lives_spin_button_set_value (GTK_SPIN_BUTTON (aspect.height_param->widgets[0]), (gdouble)height);
     g_signal_handler_unblock (aspect.height_param->widgets[0],aspect.height_func);
   }
 }
@@ -390,8 +390,8 @@ void after_aspect_width_changed (GtkSpinButton *spinbutton, gpointer user_data)
 void after_aspect_height_changed (GtkToggleButton *spinbutton, gpointer user_data){
   if (lives_toggle_button_get_active (LIVES_TOGGLE_BUTTON (aspect.checkbutton))) {
     boolean keepeven=FALSE;
-    gint height=gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spinbutton));
-    gint width=gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (aspect.width_param->widgets[0]));
+    gint height=lives_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spinbutton));
+    gint width=lives_spin_button_get_value_as_int (GTK_SPIN_BUTTON (aspect.width_param->widgets[0]));
 
     g_signal_handler_block (aspect.width_param->widgets[0],aspect.width_func);
 
@@ -412,7 +412,7 @@ void after_aspect_height_changed (GtkToggleButton *spinbutton, gpointer user_dat
       }
     }
 
-    gtk_spin_button_set_value (GTK_SPIN_BUTTON (aspect.width_param->widgets[0]), (gdouble)width);
+    lives_spin_button_set_value (GTK_SPIN_BUTTON (aspect.width_param->widgets[0]), (gdouble)width);
     g_signal_handler_unblock (aspect.width_param->widgets[0],aspect.width_func);
   }
 }
@@ -457,25 +457,25 @@ void setmergealign (void) {
   }
 
   if (cfile->end-cfile->start+1>(cb_frames*((merge_opts!=NULL&&merge_opts->spinbutton_loops!=NULL)?
-					    gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON (merge_opts->spinbutton_loops)):1))
+					    lives_spin_button_get_value_as_int(GTK_SPIN_BUTTON (merge_opts->spinbutton_loops)):1))
       &&!merge_opts->loop_to_fit) {
     // set special transalign widgets to their default values
     if (mergealign.start_param!=NULL&&mergealign.start_param->widgets[0]!=NULL&&GTK_IS_SPIN_BUTTON
 	(mergealign.start_param->widgets[0])&&(param=mergealign.start_param)->type==LIVES_PARAM_NUM) {
       if (param->dp) {
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),get_double_param (param->def));
+	lives_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),get_double_param (param->def));
       }
       else {
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)get_int_param (param->def));
+	lives_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)get_int_param (param->def));
       }
     }
     if (mergealign.end_param!=NULL&&mergealign.end_param->widgets[0]!=NULL&&GTK_IS_SPIN_BUTTON 
 	(mergealign.end_param->widgets[0])&&(param=mergealign.end_param)->type==LIVES_PARAM_NUM) {
       if (param->dp) {
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),get_double_param (param->def));
+	lives_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),get_double_param (param->def));
       }
       else {
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)get_int_param (param->def));
+	lives_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)get_int_param (param->def));
       }
     }
   }
@@ -484,22 +484,22 @@ void setmergealign (void) {
       // set special transalign widgets to min/max values
       if (mergealign.start_param!=NULL&&mergealign.start_param->widgets[0]!=NULL&&GTK_IS_SPIN_BUTTON 
 	  (mergealign.start_param->widgets[0])&&(param=mergealign.start_param)->type==LIVES_PARAM_NUM) {
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)param->min);
+	lives_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)param->min);
       }
       if (mergealign.end_param!=NULL&&mergealign.end_param->widgets[0]!=NULL&&GTK_IS_SPIN_BUTTON 
 	  (mergealign.end_param->widgets[0])&&(param=mergealign.end_param)->type==LIVES_PARAM_NUM) {
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)param->max);
+	lives_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)param->max);
       }
     }
     else {
       // set special transalign widgets to max/min values
       if (mergealign.start_param!=NULL&&mergealign.start_param->widgets[0]!=NULL&&GTK_IS_SPIN_BUTTON 
 	  (mergealign.start_param->widgets[0])&&(param=mergealign.start_param)->type==LIVES_PARAM_NUM) {
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)param->max);
+	lives_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)param->max);
       }
       if (mergealign.end_param!=NULL&&mergealign.end_param->widgets[0]!=NULL&&GTK_IS_SPIN_BUTTON 
 	  (mergealign.end_param->widgets[0])&&(param=mergealign.end_param)->type==LIVES_PARAM_NUM) {
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)param->min);
+	lives_spin_button_set_value (GTK_SPIN_BUTTON (param->widgets[0]),(gdouble)param->min);
       }
     }
   }
