@@ -458,7 +458,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
 	   if (xin_bytes==0) xin_bytes=in_bytes;
 	 }
 
-	 if (!pulsed->in_use||in_bytes==0) {
+	 if (!pulsed->in_use||in_bytes==0||pulsed->mute) {
 	   // reached end of audio with no looping
 	   sample_silence_pulse(pulsed,nframes*pulsed->out_achans*
 				(pulsed->out_asamps>>3),xbytes);
@@ -1040,7 +1040,7 @@ void set_process_callback_pulse(pulse_driver_t *pdriver, boolean activate) {
 
 int pulse_driver_activate(pulse_driver_t *pdriver) {
 // create a new client and connect it to pulse server
-  gchar *pa_clientname="LiVES_audio_out";
+  gchar *pa_clientname;
   gchar *mypid;
 
   pa_sample_spec pa_spec;
@@ -1055,6 +1055,14 @@ int pulse_driver_activate(pulse_driver_t *pdriver) {
 
   if (mainw->aplayer_broken) return 2;
 
+
+  if (pdriver->is_output) {
+    pa_clientname="LiVES_audio_out";
+  }
+  else {
+    pa_clientname="LiVES_audio_in";
+  }
+
   mypid=g_strdup_printf("%d",getpid());
 
   pdriver->pa_props=pa_proplist_new();
