@@ -709,7 +709,7 @@ on_resample_audio_activate (GtkMenuItem     *menuitem,
   mainw->fx3_val=cfile->asampsize;
   mainw->fx4_val=cfile->signed_endian;
   resaudw=create_resaudw(1,NULL,NULL);
-  gtk_widget_show (resaudw->dialog);
+  lives_widget_show (resaudw->dialog);
 
 }
 
@@ -725,9 +725,9 @@ on_resaudio_ok_clicked                      (GtkButton *button,
   boolean has_lmap_error=FALSE;
 
   if (button!=NULL) {
-    arps=arate=(int)atoi (gtk_entry_get_text(GTK_ENTRY(resaudw->entry_arate)));
-    achans=(int)atoi (gtk_entry_get_text(GTK_ENTRY(resaudw->entry_achans)));
-    asampsize=(int)atoi (gtk_entry_get_text(GTK_ENTRY(resaudw->entry_asamps)));
+    arps=arate=(int)atoi (lives_entry_get_text(GTK_ENTRY(resaudw->entry_arate)));
+    achans=(int)atoi (lives_entry_get_text(GTK_ENTRY(resaudw->entry_achans)));
+    asampsize=(int)atoi (lives_entry_get_text(GTK_ENTRY(resaudw->entry_asamps)));
     if (lives_toggle_button_get_active(LIVES_TOGGLE_BUTTON(resaudw->rb_unsigned))) {
       asigned=0;
     }
@@ -735,7 +735,7 @@ on_resaudio_ok_clicked                      (GtkButton *button,
       aendian=0;
     }
 
-    gtk_widget_destroy (resaudw->dialog);
+    lives_widget_destroy (resaudw->dialog);
     mainw->noswitch=TRUE;
     lives_widget_context_update();
     mainw->noswitch=noswitch;
@@ -879,45 +879,45 @@ static void on_resaudw_achans_changed (GtkWidget *widg, gpointer user_data) {
   gchar *tmp;
 
   if (!lives_toggle_button_get_active(LIVES_TOGGLE_BUTTON(widg))) {
-    gtk_widget_set_sensitive (resaudw->rb_signed,FALSE);
-    gtk_widget_set_sensitive (resaudw->rb_unsigned,FALSE);
-    gtk_widget_set_sensitive (resaudw->rb_bigend,FALSE);
-    gtk_widget_set_sensitive (resaudw->rb_littleend,FALSE);
-    gtk_widget_set_sensitive (resaudw->entry_arate,FALSE);
-    gtk_widget_set_sensitive (resaudw->entry_asamps,FALSE);
-    gtk_widget_set_sensitive (resaudw->entry_achans,FALSE);
+    lives_widget_set_sensitive (resaudw->rb_signed,FALSE);
+    lives_widget_set_sensitive (resaudw->rb_unsigned,FALSE);
+    lives_widget_set_sensitive (resaudw->rb_bigend,FALSE);
+    lives_widget_set_sensitive (resaudw->rb_littleend,FALSE);
+    lives_widget_set_sensitive (resaudw->entry_arate,FALSE);
+    lives_widget_set_sensitive (resaudw->entry_asamps,FALSE);
+    lives_widget_set_sensitive (resaudw->entry_achans,FALSE);
     if (prefsw!=NULL) {
-      gtk_widget_set_sensitive (prefsw->pertrack_checkbutton,FALSE);
-      gtk_widget_set_sensitive (prefsw->backaudio_checkbutton,FALSE);
+      lives_widget_set_sensitive (prefsw->pertrack_checkbutton,FALSE);
+      lives_widget_set_sensitive (prefsw->backaudio_checkbutton,FALSE);
       lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON(prefsw->pertrack_checkbutton),FALSE);
       lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON(prefsw->backaudio_checkbutton),FALSE);
     }
     else if (rdet!=NULL) {
       lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON(rdet->pertrack_checkbutton),FALSE);
       lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON(rdet->backaudio_checkbutton),FALSE);
-      gtk_widget_set_sensitive(rdet->pertrack_checkbutton,FALSE);
-      gtk_widget_set_sensitive(rdet->backaudio_checkbutton,FALSE);
+      lives_widget_set_sensitive(rdet->pertrack_checkbutton,FALSE);
+      lives_widget_set_sensitive(rdet->backaudio_checkbutton,FALSE);
     }
   }
   else {
-    if (atoi (gtk_entry_get_text (GTK_ENTRY (resaudw->entry_asamps)))!=8) {
-      gtk_widget_set_sensitive (resaudw->rb_bigend,TRUE);
-      gtk_widget_set_sensitive (resaudw->rb_littleend,TRUE);
+    if (atoi (lives_entry_get_text (GTK_ENTRY (resaudw->entry_asamps)))!=8) {
+      lives_widget_set_sensitive (resaudw->rb_bigend,TRUE);
+      lives_widget_set_sensitive (resaudw->rb_littleend,TRUE);
     }
-    gtk_widget_set_sensitive (resaudw->entry_arate,TRUE);
-    gtk_widget_set_sensitive (resaudw->entry_asamps,TRUE);
-    gtk_widget_set_sensitive (resaudw->entry_achans,TRUE);
+    lives_widget_set_sensitive (resaudw->entry_arate,TRUE);
+    lives_widget_set_sensitive (resaudw->entry_asamps,TRUE);
+    lives_widget_set_sensitive (resaudw->entry_achans,TRUE);
     if (prefsw!=NULL) {
-      gtk_widget_set_sensitive (prefsw->pertrack_checkbutton,TRUE);
-      gtk_widget_set_sensitive (prefsw->backaudio_checkbutton,TRUE);
+      lives_widget_set_sensitive (prefsw->pertrack_checkbutton,TRUE);
+      lives_widget_set_sensitive (prefsw->backaudio_checkbutton,TRUE);
     }
     if (rdet!=NULL) {
-      gtk_widget_set_sensitive(rdet->backaudio_checkbutton,TRUE);
-      gtk_widget_set_sensitive(rdet->pertrack_checkbutton,TRUE);
+      lives_widget_set_sensitive(rdet->backaudio_checkbutton,TRUE);
+      lives_widget_set_sensitive(rdet->pertrack_checkbutton,TRUE);
     }
 
     tmp=g_strdup_printf ("%d",DEFAULT_AUDIO_CHANS);
-    gtk_entry_set_text (GTK_ENTRY (resaudw->entry_achans),tmp);
+    lives_entry_set_text (GTK_ENTRY (resaudw->entry_achans),tmp);
     g_free (tmp);
 
   }
@@ -928,19 +928,19 @@ static void on_resaudw_achans_changed (GtkWidget *widg, gpointer user_data) {
 
 void 
 on_resaudw_asamps_changed (GtkWidget *irrelevant, gpointer rubbish) {
-  if (atoi (gtk_entry_get_text (GTK_ENTRY (resaudw->entry_asamps)))==8) {
-    gtk_widget_set_sensitive (resaudw->rb_bigend,FALSE);
-    gtk_widget_set_sensitive (resaudw->rb_littleend,FALSE);
-    gtk_widget_set_sensitive (resaudw->rb_signed,FALSE);
-    gtk_widget_set_sensitive (resaudw->rb_unsigned,TRUE);
+  if (atoi (lives_entry_get_text (GTK_ENTRY (resaudw->entry_asamps)))==8) {
+    lives_widget_set_sensitive (resaudw->rb_bigend,FALSE);
+    lives_widget_set_sensitive (resaudw->rb_littleend,FALSE);
+    lives_widget_set_sensitive (resaudw->rb_signed,FALSE);
+    lives_widget_set_sensitive (resaudw->rb_unsigned,TRUE);
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(resaudw->rb_unsigned),TRUE);
   }
   else {
-    gtk_widget_set_sensitive (resaudw->rb_bigend,TRUE);
-    gtk_widget_set_sensitive (resaudw->rb_littleend,TRUE);
-    if (atoi (gtk_entry_get_text (GTK_ENTRY (resaudw->entry_asamps)))==16) {
-      gtk_widget_set_sensitive (resaudw->rb_signed,TRUE);
-      gtk_widget_set_sensitive (resaudw->rb_unsigned,FALSE);
+    lives_widget_set_sensitive (resaudw->rb_bigend,TRUE);
+    lives_widget_set_sensitive (resaudw->rb_littleend,TRUE);
+    if (atoi (lives_entry_get_text (GTK_ENTRY (resaudw->entry_asamps)))==16) {
+      lives_widget_set_sensitive (resaudw->rb_signed,TRUE);
+      lives_widget_set_sensitive (resaudw->rb_unsigned,FALSE);
       lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(resaudw->rb_signed),TRUE);
     }
   }
@@ -1204,7 +1204,7 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
     resaudw->dialog = lives_standard_dialog_new (title,FALSE);
     g_free(title);
 
-    accel_group = GTK_ACCEL_GROUP(gtk_accel_group_new ());
+    accel_group = GTK_ACCEL_GROUP(lives_accel_group_new ());
     gtk_window_add_accel_group (GTK_WINDOW (resaudw->dialog), accel_group);
 
     if (prefs->show_gui) {
@@ -1215,23 +1215,23 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
 
     vboxx = lives_vbox_new (FALSE, 0);
 
-    gtk_box_pack_start (GTK_BOX (dialog_vbox), vboxx, TRUE, TRUE, 0);
+    lives_box_pack_start (GTK_BOX (dialog_vbox), vboxx, TRUE, TRUE, 0);
   }
   else vboxx=top_vbox;
 
   if (type==1) {
     frame = gtk_frame_new (NULL);
  
-    gtk_box_pack_start (GTK_BOX (vboxx), frame, TRUE, TRUE, 0);
+    lives_box_pack_start (GTK_BOX (vboxx), frame, TRUE, TRUE, 0);
     
     if (palette->style&STYLE_1) {
       lives_widget_set_bg_color (frame, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
     }
     
     hbox2 = lives_hbox_new (FALSE, 0);
-    gtk_widget_show (hbox2);
-    gtk_container_add (GTK_CONTAINER (frame), hbox2);
-    gtk_container_set_border_width (GTK_CONTAINER (hbox2), widget_opts.packing_width);
+    lives_widget_show (hbox2);
+    lives_container_add (GTK_CONTAINER (frame), hbox2);
+    lives_container_set_border_width (GTK_CONTAINER (hbox2), widget_opts.packing_width);
     
     tmp=g_strdup_printf ("%d",(int)mainw->fx1_val);
     
@@ -1256,20 +1256,20 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
     lives_widget_set_can_focus (combo_entry1, FALSE);
 
     vseparator = lives_vseparator_new ();
-    gtk_widget_show (vseparator);
-    gtk_box_pack_start (GTK_BOX (hbox2), vseparator, FALSE, FALSE, widget_opts.packing_width);
+    lives_widget_show (vseparator);
+    lives_box_pack_start (GTK_BOX (hbox2), vseparator, FALSE, FALSE, widget_opts.packing_width);
 
     vbox = lives_vbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (hbox2), vbox, FALSE, FALSE, 0);
+    lives_box_pack_start (GTK_BOX (hbox2), vbox, FALSE, FALSE, 0);
 
     hbox = lives_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+    lives_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
     radiobutton_s1 = lives_standard_radio_button_new (_("Signed"),FALSE,s1_group,LIVES_BOX(hbox),NULL);
     s1_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (radiobutton_s1));
 
     hbox = lives_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+    lives_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
     radiobutton_u1 = lives_standard_radio_button_new (_("Unsigned"),FALSE,s1_group,LIVES_BOX(hbox),NULL);
 
@@ -1282,23 +1282,23 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
       lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON (radiobutton_s1), TRUE);
     }
 
-    gtk_widget_set_sensitive (radiobutton_u1, FALSE);
-    gtk_widget_set_sensitive (radiobutton_s1, FALSE);
+    lives_widget_set_sensitive (radiobutton_u1, FALSE);
+    lives_widget_set_sensitive (radiobutton_s1, FALSE);
 
     vseparator = lives_vseparator_new ();
-    gtk_box_pack_start (GTK_BOX (hbox2), vseparator, FALSE, FALSE, widget_opts.packing_width);
+    lives_box_pack_start (GTK_BOX (hbox2), vseparator, FALSE, FALSE, widget_opts.packing_width);
     
     vbox = lives_vbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (hbox2), vbox, FALSE, FALSE, 0);
+    lives_box_pack_start (GTK_BOX (hbox2), vbox, FALSE, FALSE, 0);
 
     hbox = lives_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+    lives_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
     radiobutton_l1 = lives_standard_radio_button_new (_("Little Endian"),FALSE,e1_group,LIVES_BOX(hbox),NULL);
     e1_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (radiobutton_l1));
 
     hbox = lives_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+    lives_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
     radiobutton_b1 = lives_standard_radio_button_new (_("Big Endian"),FALSE,e1_group,LIVES_BOX(hbox),NULL);
 
@@ -1309,8 +1309,8 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
       lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON (radiobutton_l1), TRUE);
     }
 
-    gtk_widget_set_sensitive (radiobutton_b1, FALSE);
-    gtk_widget_set_sensitive (radiobutton_l1, FALSE);
+    lives_widget_set_sensitive (radiobutton_b1, FALSE);
+    lives_widget_set_sensitive (radiobutton_l1, FALSE);
 
     label = lives_standard_label_new (_("Current"));
 
@@ -1323,19 +1323,19 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
   if (type<9||type==11) {
     frame = gtk_frame_new (NULL);
 
-    if (type==4) gtk_box_pack_start (GTK_BOX (vboxx), frame, FALSE, FALSE, widget_opts.packing_height);
-    else gtk_box_pack_start (GTK_BOX (vboxx), frame, TRUE, TRUE, 0);
+    if (type==4) lives_box_pack_start (GTK_BOX (vboxx), frame, FALSE, FALSE, widget_opts.packing_height);
+    else lives_box_pack_start (GTK_BOX (vboxx), frame, TRUE, TRUE, 0);
 
     if (palette->style&STYLE_1) {
       lives_widget_set_bg_color (frame, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
     }
 
     vbox2 = lives_vbox_new (FALSE, 0);
-    gtk_container_add (GTK_CONTAINER (frame), vbox2);
+    lives_container_add (GTK_CONTAINER (frame), vbox2);
     
     if (type>2&&type<5) {
       resaudw->aud_hbox = lives_hbox_new (FALSE, 0);
-      gtk_box_pack_start (GTK_BOX (vbox2), resaudw->aud_hbox, FALSE, FALSE, 0);
+      lives_box_pack_start (GTK_BOX (vbox2), resaudw->aud_hbox, FALSE, FALSE, 0);
 
       resaudw->aud_checkbutton = lives_standard_check_button_new (_("_Enable audio"),TRUE,LIVES_BOX(resaudw->aud_hbox),NULL);
 
@@ -1345,35 +1345,35 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
     else resaudw->aud_checkbutton = gtk_check_button_new ();
 
     hbox2 = lives_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, widget_opts.packing_height);
-    gtk_container_set_border_width (GTK_CONTAINER (hbox2), widget_opts.border_width);
+    lives_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, widget_opts.packing_height);
+    lives_container_set_border_width (GTK_CONTAINER (hbox2), widget_opts.border_width);
 
     vbox = lives_vbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (hbox2), vbox, FALSE, FALSE, widget_opts.packing_width);
+    lives_box_pack_start (GTK_BOX (hbox2), vbox, FALSE, FALSE, widget_opts.packing_width);
 
     hbox = lives_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
-    gtk_container_set_border_width (GTK_CONTAINER (hbox), widget_opts.border_width);
+    lives_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+    lives_container_set_border_width (GTK_CONTAINER (hbox), widget_opts.border_width);
 
     combo4 = lives_standard_combo_new (_("Rate (Hz) "),type>=3&&type!=11,rate,LIVES_BOX(hbox),NULL);
     
     resaudw->entry_arate = lives_combo_get_entry(LIVES_COMBO(combo4));
 
     gtk_entry_set_width_chars (GTK_ENTRY (resaudw->entry_arate), 6);
-    if (type==7) gtk_widget_set_sensitive(combo4,FALSE);
+    if (type==7) lives_widget_set_sensitive(combo4,FALSE);
   
     if (type<3||(type>4&&type<8)||type==11) tmp=g_strdup_printf ("%d",(int)mainw->fx1_val);
     else if (type==8) tmp=g_strdup_printf ("%d",DEFAULT_AUDIO_RATE);
     else if (type==3) tmp=g_strdup_printf ("%d",rdet->arate);
     else tmp=g_strdup_printf ("%d",prefs->mt_def_arate);
-    gtk_entry_set_text (GTK_ENTRY (resaudw->entry_arate),tmp);
+    lives_entry_set_text (GTK_ENTRY (resaudw->entry_arate),tmp);
     g_free (tmp);
 
     combo5 = lives_standard_combo_new ((type>=3&&type!=11?(_("_Channels")):(_("Channels"))),type>=3&&type!=11,
 				       channels,LIVES_BOX(hbox),NULL);
     
 
-    if (type==7) gtk_widget_set_sensitive(combo5,FALSE);
+    if (type==7) lives_widget_set_sensitive(combo5,FALSE);
 
     resaudw->entry_achans = lives_combo_get_entry(LIVES_COMBO(combo5));
     gtk_entry_set_width_chars (GTK_ENTRY (resaudw->entry_achans), 2);
@@ -1382,19 +1382,19 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
     else if (type==8) tmp=g_strdup_printf ("%d",DEFAULT_AUDIO_CHANS);
     else if (type==3) tmp=g_strdup_printf ("%d",rdet->achans);
     else tmp=g_strdup_printf ("%d",prefs->mt_def_achans==0?DEFAULT_AUDIO_CHANS:prefs->mt_def_achans);
-    gtk_entry_set_text (GTK_ENTRY (resaudw->entry_achans),tmp);
+    lives_entry_set_text (GTK_ENTRY (resaudw->entry_achans),tmp);
     g_free (tmp);
     
     if (chans_fixed) {
-      gtk_widget_set_sensitive(resaudw->entry_achans,FALSE);
-      gtk_widget_set_sensitive(combo5,FALSE);
+      lives_widget_set_sensitive(resaudw->entry_achans,FALSE);
+      lives_widget_set_sensitive(combo5,FALSE);
     }
 
  
     combo6 = lives_standard_combo_new ((type>=3&&type!=11?(_("_Sample Size")):(_("Sample Size"))),type>=3&&type!=11,
 				       sampsize,LIVES_BOX(hbox),NULL);
 
-    if (type==7) gtk_widget_set_sensitive(combo6,FALSE);
+    if (type==7) lives_widget_set_sensitive(combo6,FALSE);
 
     resaudw->entry_asamps = lives_combo_get_entry(LIVES_COMBO(combo6));
     gtk_entry_set_max_length (GTK_ENTRY (resaudw->entry_asamps), 2);
@@ -1405,7 +1405,7 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
     else if (type==8) tmp=g_strdup_printf ("%d",DEFAULT_AUDIO_SAMPS);
     else if (type==3) tmp=g_strdup_printf ("%d",rdet->asamps);
     else tmp=g_strdup_printf ("%d",prefs->mt_def_asamps);
-    gtk_entry_set_text (GTK_ENTRY (resaudw->entry_asamps),tmp);
+    lives_entry_set_text (GTK_ENTRY (resaudw->entry_asamps),tmp);
 
     if (!strcmp(tmp,"8")) is_8bit=TRUE;
     else is_8bit=FALSE;
@@ -1413,28 +1413,28 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
     g_free (tmp);
 
     vseparator = lives_vseparator_new ();
-    gtk_widget_show (vseparator);
-    if (type!=4) gtk_box_pack_start (GTK_BOX (hbox2), vseparator, FALSE, FALSE, widget_opts.packing_width);
+    lives_widget_show (vseparator);
+    if (type!=4) lives_box_pack_start (GTK_BOX (hbox2), vseparator, FALSE, FALSE, widget_opts.packing_width);
 
     vbox = lives_vbox_new (FALSE, 0);
-    if (type!=4) gtk_box_pack_start (GTK_BOX (hbox2), vbox, FALSE, FALSE, 0);
+    if (type!=4) lives_box_pack_start (GTK_BOX (hbox2), vbox, FALSE, FALSE, 0);
 
     hbox = lives_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+    lives_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
     resaudw->rb_signed = lives_standard_radio_button_new (_("Signed"),FALSE,s2_group,LIVES_BOX(hbox),NULL);
     s2_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (resaudw->rb_signed));
 
     lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON (resaudw->rb_signed), TRUE);
-    if (type==7||is_8bit) gtk_widget_set_sensitive(resaudw->rb_signed,FALSE);
+    if (type==7||is_8bit) lives_widget_set_sensitive(resaudw->rb_signed,FALSE);
     
 
     hbox = lives_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+    lives_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
     resaudw->rb_unsigned = lives_standard_radio_button_new (_("Unsigned"),FALSE,s2_group,LIVES_BOX(hbox),NULL);
 
-    if (type==7||!is_8bit) gtk_widget_set_sensitive(resaudw->rb_unsigned,FALSE);
+    if (type==7||!is_8bit) lives_widget_set_sensitive(resaudw->rb_unsigned,FALSE);
 
     if (type<3||(type>4&&type<8)||type==11) aendian=mainw->fx4_val;
     else if (type==8) aendian=DEFAULT_AUDIO_SIGNED16|((capable->byte_order==LIVES_BIG_ENDIAN)?AFORM_BIG_ENDIAN:0);
@@ -1449,25 +1449,25 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
     }
 
     vseparator = lives_vseparator_new ();
-    gtk_box_pack_start (GTK_BOX (hbox2), vseparator, FALSE, FALSE, widget_opts.packing_width);
+    lives_box_pack_start (GTK_BOX (hbox2), vseparator, FALSE, FALSE, widget_opts.packing_width);
 
     vbox = lives_vbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (hbox2), vbox, FALSE, FALSE, 0);
+    lives_box_pack_start (GTK_BOX (hbox2), vbox, FALSE, FALSE, 0);
 
     hbox = lives_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+    lives_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
     resaudw->rb_littleend = lives_standard_radio_button_new (_("Little Endian"),FALSE,e2_group,LIVES_BOX(hbox),NULL);
     e2_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (resaudw->rb_littleend));
 
-    if (type==7) gtk_widget_set_sensitive(resaudw->rb_littleend,FALSE);
+    if (type==7) lives_widget_set_sensitive(resaudw->rb_littleend,FALSE);
 
     hbox = lives_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+    lives_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
     resaudw->rb_bigend = lives_standard_radio_button_new (_("Big Endian"),FALSE,e2_group,LIVES_BOX(hbox),NULL);
 
-    if (type==7) gtk_widget_set_sensitive(resaudw->rb_bigend,FALSE);
+    if (type==7) lives_widget_set_sensitive(resaudw->rb_bigend,FALSE);
 
     if (aendian&AFORM_BIG_ENDIAN) {
       lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON (resaudw->rb_bigend), TRUE);
@@ -1476,9 +1476,9 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
       lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON (resaudw->rb_littleend), TRUE);
     }
 
-    if (!strcmp(gtk_entry_get_text (GTK_ENTRY (resaudw->entry_asamps)),"8")) {
-      gtk_widget_set_sensitive (resaudw->rb_littleend, FALSE);
-      gtk_widget_set_sensitive (resaudw->rb_bigend, FALSE);
+    if (!strcmp(lives_entry_get_text (GTK_ENTRY (resaudw->entry_asamps)),"8")) {
+      lives_widget_set_sensitive (resaudw->rb_littleend, FALSE);
+      lives_widget_set_sensitive (resaudw->rb_bigend, FALSE);
     }
 
     g_signal_connect (GTK_OBJECT(resaudw->entry_asamps), "changed",
@@ -1496,17 +1496,17 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
 
   if (type>7&&type!=11) {
     frame = gtk_frame_new (NULL);
-    gtk_widget_show (frame);
-    gtk_box_pack_start (GTK_BOX (vboxx), frame, TRUE, TRUE, 0);
+    lives_widget_show (frame);
+    lives_box_pack_start (GTK_BOX (vboxx), frame, TRUE, TRUE, 0);
 
     if (palette->style&STYLE_1) {
       lives_widget_set_bg_color (frame, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
     }
     
     hbox = lives_hbox_new (FALSE, 0);
-    gtk_widget_show (hbox);
-    gtk_container_add (GTK_CONTAINER (frame), hbox);
-    gtk_container_set_border_width (GTK_CONTAINER (hbox), widget_opts.border_width);
+    lives_widget_show (hbox);
+    lives_container_add (GTK_CONTAINER (frame), hbox);
+    lives_container_set_border_width (GTK_CONTAINER (hbox), widget_opts.border_width);
     
 
     resaudw->fps_spinbutton = lives_standard_spin_button_new (_("_Frames Per Second "),TRUE,
@@ -1522,8 +1522,8 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
     lives_box_set_spacing(GTK_BOX(dialog_vbox),widget_opts.packing_height*3);
     
     hbox = lives_hbox_new (FALSE, 0);
-    gtk_widget_show (hbox);
-    gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, TRUE, TRUE, widget_opts.packing_height);
+    lives_widget_show (hbox);
+    lives_box_pack_start (GTK_BOX (dialog_vbox), hbox, TRUE, TRUE, widget_opts.packing_height);
     
     if (type!=6&&type!=7) {
 
@@ -1539,8 +1539,8 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
 
 
       hbox = lives_hbox_new (FALSE, 0);
-      gtk_widget_show (hbox);
-      gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, TRUE, TRUE, widget_opts.packing_height);
+      lives_widget_show (hbox);
+      lives_box_pack_start (GTK_BOX (dialog_vbox), hbox, TRUE, TRUE, widget_opts.packing_height);
 
       resaudw->unlim_radiobutton=lives_standard_radio_button_new(_("Unlimited"),FALSE,rbgroup,LIVES_BOX(hbox),NULL);
       rbgroup = lives_radio_button_get_group (LIVES_RADIO_BUTTON (resaudw->unlim_radiobutton));
@@ -1555,33 +1555,33 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
 
     if (type<8||type==11) {
       hseparator = lives_hseparator_new ();
-      gtk_widget_show (hseparator);
-      gtk_box_pack_start (GTK_BOX (dialog_vbox), hseparator, TRUE, TRUE, 0);
+      lives_widget_show (hseparator);
+      lives_box_pack_start (GTK_BOX (dialog_vbox), hseparator, TRUE, TRUE, 0);
       
       label=lives_standard_label_new(_("Click OK to begin recording, or Cancel to quit."));
 
-      gtk_box_pack_start (GTK_BOX (dialog_vbox), label, TRUE, TRUE, 0);
+      lives_box_pack_start (GTK_BOX (dialog_vbox), label, TRUE, TRUE, 0);
     }
   }
 
 
   if (type<3||type>4) {
     dialog_action_area = lives_dialog_get_action_area(LIVES_DIALOG (resaudw->dialog));
-    gtk_widget_show (dialog_action_area);
+    lives_widget_show (dialog_action_area);
     gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_END);
     
     cancelbutton = gtk_button_new_from_stock ("gtk-cancel");
  
-    gtk_dialog_add_action_widget (GTK_DIALOG (resaudw->dialog), cancelbutton, GTK_RESPONSE_CANCEL);
+    lives_dialog_add_action_widget (GTK_DIALOG (resaudw->dialog), cancelbutton, GTK_RESPONSE_CANCEL);
     lives_widget_set_can_focus_and_default (cancelbutton);
     
-    if (accel_group!=NULL) gtk_widget_add_accelerator (cancelbutton, "activate", accel_group,
+    if (accel_group!=NULL) lives_widget_add_accelerator (cancelbutton, "activate", accel_group,
 						       LIVES_KEY_Escape, (GdkModifierType)0, (GtkAccelFlags)0);
     
       
     okbutton = gtk_button_new_from_stock ("gtk-ok");
  
-    gtk_dialog_add_action_widget (GTK_DIALOG (resaudw->dialog), okbutton, GTK_RESPONSE_OK);
+    lives_dialog_add_action_widget (GTK_DIALOG (resaudw->dialog), okbutton, GTK_RESPONSE_OK);
     lives_widget_set_can_focus_and_default (okbutton);
     gtk_widget_grab_default (okbutton);
 
@@ -1613,7 +1613,7 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
       
     }
 
-    gtk_widget_show_all(resaudw->dialog);
+    lives_widget_show_all(resaudw->dialog);
 
   }
   else {
@@ -1625,9 +1625,9 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
     }
   }
 
-  gtk_widget_show_all(vboxx);
+  lives_widget_show_all(vboxx);
 
-  if (type==2) gtk_widget_hide (label_aud);
+  if (type==2) lives_widget_hide (label_aud);
 
   g_list_free (channels);
   g_list_free (sampsize);
@@ -1676,9 +1676,9 @@ void create_new_pb_speed (short type) {
   new_pb_speed = lives_standard_dialog_new (title,FALSE);
   g_free(title);
 
-  gtk_container_set_border_width (GTK_CONTAINER (new_pb_speed), widget_opts.border_width*2);
+  lives_container_set_border_width (GTK_CONTAINER (new_pb_speed), widget_opts.border_width*2);
 
-  accel_group = GTK_ACCEL_GROUP(gtk_accel_group_new ());
+  accel_group = GTK_ACCEL_GROUP(lives_accel_group_new ());
   gtk_window_add_accel_group (GTK_WINDOW (new_pb_speed), accel_group);
 
   if (prefs->show_gui) {
@@ -1689,7 +1689,7 @@ void create_new_pb_speed (short type) {
 
   vbox = lives_vbox_new (FALSE, 0);
   
-  gtk_box_pack_start (GTK_BOX (dialog_vbox), vbox, TRUE, TRUE, widget_opts.packing_height*2);
+  lives_box_pack_start (GTK_BOX (dialog_vbox), vbox, TRUE, TRUE, widget_opts.packing_height*2);
 
   if (type==1) {
     g_snprintf(label_text,256,
@@ -1705,8 +1705,8 @@ void create_new_pb_speed (short type) {
   label=lives_standard_label_new_with_mnemonic(label_text,NULL);
 
   hbox = lives_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, widget_opts.packing_height);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+  lives_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, widget_opts.packing_height);
+  lives_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
   if (type==2) {
     add_fill_to_box(LIVES_BOX(hbox));
@@ -1721,10 +1721,10 @@ void create_new_pb_speed (short type) {
     spinbutton_pb_speed = lives_standard_spin_button_new (NULL,FALSE,cfile->fps,1.,FPS_MAX,.01,.1,3,LIVES_BOX(hbox),NULL);
 
     label2=lives_standard_label_new_with_mnemonic(_("OR enter the desired clip length in _seconds"),NULL);
-    gtk_box_pack_start (GTK_BOX (vbox), label2, TRUE, TRUE, widget_opts.packing_height);
+    lives_box_pack_start (GTK_BOX (vbox), label2, TRUE, TRUE, widget_opts.packing_height);
 
     hbox = lives_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+    lives_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
     radiobutton2 = lives_standard_radio_button_new (NULL,FALSE,rbgroup,LIVES_BOX(hbox),NULL);
 
@@ -1744,24 +1744,24 @@ void create_new_pb_speed (short type) {
   change_audio_speed = lives_standard_check_button_new
     (_("Change the _audio speed as well"),TRUE,LIVES_BOX(ca_hbox),NULL);
 
-  gtk_box_pack_start (GTK_BOX (vbox), ca_hbox, TRUE, TRUE, widget_opts.packing_height);
+  lives_box_pack_start (GTK_BOX (vbox), ca_hbox, TRUE, TRUE, widget_opts.packing_height);
 
 
   dialog_action_area = lives_dialog_get_action_area(LIVES_DIALOG (new_pb_speed));
   gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_END);
 
   cancelbutton = gtk_button_new_from_stock ("gtk-cancel");
-  gtk_dialog_add_action_widget (GTK_DIALOG (new_pb_speed), cancelbutton, GTK_RESPONSE_CANCEL);
+  lives_dialog_add_action_widget (GTK_DIALOG (new_pb_speed), cancelbutton, GTK_RESPONSE_CANCEL);
   lives_widget_set_can_focus (cancelbutton,TRUE);
 
-  gtk_widget_add_accelerator (cancelbutton, "activate", accel_group,
+  lives_widget_add_accelerator (cancelbutton, "activate", accel_group,
                               LIVES_KEY_Escape, (GdkModifierType)0, (GtkAccelFlags)0);
 
   change_pb_ok = gtk_button_new_from_stock ("gtk-ok");
-  gtk_dialog_add_action_widget (GTK_DIALOG (new_pb_speed), change_pb_ok, GTK_RESPONSE_OK);
+  lives_dialog_add_action_widget (GTK_DIALOG (new_pb_speed), change_pb_ok, GTK_RESPONSE_OK);
   lives_widget_set_can_focus_and_default (change_pb_ok);
   gtk_widget_grab_default (change_pb_ok);
-  gtk_widget_grab_focus(spinbutton_pb_speed);
+  lives_widget_grab_focus(spinbutton_pb_speed);
 
 
   reorder_leave_back=FALSE;
@@ -1801,10 +1801,10 @@ void create_new_pb_speed (short type) {
 		      &mainw->fx2_bool);
   }
 
-  gtk_widget_show_all (new_pb_speed);
+  lives_widget_show_all (new_pb_speed);
 
   if (type!=1||cfile->achans==0) {
-    gtk_widget_hide (ca_hbox);
+    lives_widget_hide (ca_hbox);
   }
 
 }
