@@ -2596,12 +2596,7 @@ LiVESWidget *lives_standard_dialog_new(const char *title, boolean add_std_button
   lives_widget_set_hexpand(dialog,TRUE);
   lives_widget_set_vexpand(dialog,TRUE);
 
-  if (prefs->gui_monitor!=0) {
-    gtk_window_set_screen(GTK_WINDOW(dialog),mainw->mgeom[prefs->gui_monitor-1].screen);
-  }
-
   lives_container_set_border_width (GTK_CONTAINER (dialog), widget_opts.border_width*2);
-  gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ALWAYS);
 
   if (widget_opts.apply_theme) {
     lives_widget_apply_theme(dialog, LIVES_WIDGET_STATE_NORMAL);
@@ -2611,6 +2606,9 @@ LiVESWidget *lives_standard_dialog_new(const char *title, boolean add_std_button
 #endif
   }
 
+  // do this before widget_show(), then call lives_window_center() afterwards
+  gtk_window_set_position(GTK_WINDOW(dialog),GTK_WIN_POS_CENTER_ALWAYS);
+
   if (add_std_buttons) {
     GtkAccelGroup *accel_group=GTK_ACCEL_GROUP(lives_accel_group_new ());
     GtkWidget *cancelbutton = gtk_button_new_from_stock ("gtk-cancel");
@@ -2636,13 +2634,14 @@ LiVESWidget *lives_standard_dialog_new(const char *title, boolean add_std_button
                       NULL);
 
   // must do this before setting modal !
-  if (!widget_opts.no_gui) 
+  if (!widget_opts.no_gui) {
     lives_widget_show(dialog);
+    lives_window_center(LIVES_WINDOW(dialog));
+  }
 
   if (!widget_opts.non_modal)
     gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 
-
 #endif
 
   return dialog;
@@ -2658,7 +2657,9 @@ LiVESWidget *lives_standard_hruler_new(void) {
 #if GTK_CHECK_VERSION(3,0,0)
   hruler=gtk_scale_new(GTK_ORIENTATION_HORIZONTAL,NULL);
   gtk_scale_set_draw_value(GTK_SCALE(hruler),FALSE);
+#if GTK_CHECK_VERSION(3,4,0)
   gtk_scale_set_has_origin(GTK_SCALE(hruler),FALSE);
+#endif
   gtk_scale_set_digits(GTK_SCALE(hruler),8);
 #else
   hruler=gtk_hruler_new();
@@ -2785,6 +2786,24 @@ LIVES_INLINE void lives_widget_apply_theme(LiVESWidget *widget, LiVESWidgetState
 }
 
 
+void lives_window_center(LiVESWindow *window) {
+  if (prefs->show_gui) {
+    if (prefs->gui_monitor>0) {
+      int xcen,ycen;
+      gtk_window_set_screen(GTK_WINDOW(window),mainw->mgeom[prefs->gui_monitor-1].screen);
+
+      xcen=mainw->mgeom[prefs->gui_monitor-1].x+(mainw->mgeom[prefs->gui_monitor-1].width-
+						 lives_widget_get_allocation_width(LIVES_WIDGET(window)))/2;
+      ycen=mainw->mgeom[prefs->gui_monitor-1].y+(mainw->mgeom[prefs->gui_monitor-1].height-
+						 lives_widget_get_allocation_height(LIVES_WIDGET(window)))/2;
+      lives_window_move(LIVES_WINDOW(window),xcen,ycen);
+    }
+    else gtk_window_set_position(GTK_WINDOW(window),GTK_WIN_POS_CENTER_ALWAYS);
+  }
+}
+
+
+
 void lives_widget_get_bg_color(LiVESWidget *widget, LiVESWidgetColor *color) {
   lives_widget_get_bg_state_color(widget,LIVES_WIDGET_STATE_NORMAL,color);
 }
